"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .address import Address, AddressTypedDict
from .alreadyactivesubscriptionerror import (
    AlreadyActiveSubscriptionError,
    AlreadyActiveSubscriptionErrorData,
)
from .alreadycanceledsubscription import (
    AlreadyCanceledSubscription,
    AlreadyCanceledSubscriptionData,
)
from .assignee import Assignee, AssigneeTypedDict
from .attachedcustomfield import AttachedCustomField, AttachedCustomFieldTypedDict
from .attachedcustomfieldcreate import (
    AttachedCustomFieldCreate,
    AttachedCustomFieldCreateTypedDict,
)
from .author import Author, AuthorTypedDict
from .authorizationcodetokenrequest import (
    AuthorizationCodeTokenRequest,
    AuthorizationCodeTokenRequestTypedDict,
)
from .authorizeorganization import AuthorizeOrganization, AuthorizeOrganizationTypedDict
from .authorizeresponseorganization import (
    AuthorizeResponseOrganization,
    AuthorizeResponseOrganizationTypedDict,
)
from .authorizeresponseuser import AuthorizeResponseUser, AuthorizeResponseUserTypedDict
from .authorizeuser import AuthorizeUser, AuthorizeUserTypedDict
from .benefit import Benefit, BenefitTypedDict
from .benefitbase import BenefitBase, BenefitBaseTypedDict
from .benefitcreate import BenefitCreate, BenefitCreateTypedDict
from .benefitcustom import BenefitCustom, BenefitCustomTypedDict
from .benefitcustomcreate import BenefitCustomCreate, BenefitCustomCreateTypedDict
from .benefitcustomcreateproperties import (
    BenefitCustomCreateProperties,
    BenefitCustomCreatePropertiesTypedDict,
)
from .benefitcustomproperties import (
    BenefitCustomProperties,
    BenefitCustomPropertiesTypedDict,
)
from .benefitcustomsubscriber import (
    BenefitCustomSubscriber,
    BenefitCustomSubscriberTypedDict,
)
from .benefitcustomsubscriberproperties import (
    BenefitCustomSubscriberProperties,
    BenefitCustomSubscriberPropertiesTypedDict,
)
from .benefitcustomupdate import BenefitCustomUpdate, BenefitCustomUpdateTypedDict
from .benefitdiscord import BenefitDiscord, BenefitDiscordTypedDict
from .benefitdiscordcreate import BenefitDiscordCreate, BenefitDiscordCreateTypedDict
from .benefitdiscordcreateproperties import (
    BenefitDiscordCreateProperties,
    BenefitDiscordCreatePropertiesTypedDict,
)
from .benefitdiscordproperties import (
    BenefitDiscordProperties,
    BenefitDiscordPropertiesTypedDict,
)
from .benefitdiscordsubscriber import (
    BenefitDiscordSubscriber,
    BenefitDiscordSubscriberTypedDict,
)
from .benefitdiscordsubscriberproperties import (
    BenefitDiscordSubscriberProperties,
    BenefitDiscordSubscriberPropertiesTypedDict,
)
from .benefitdiscordupdate import BenefitDiscordUpdate, BenefitDiscordUpdateTypedDict
from .benefitdownloadables import BenefitDownloadables, BenefitDownloadablesTypedDict
from .benefitdownloadablescreate import (
    BenefitDownloadablesCreate,
    BenefitDownloadablesCreateTypedDict,
)
from .benefitdownloadablescreateproperties import (
    BenefitDownloadablesCreateProperties,
    BenefitDownloadablesCreatePropertiesTypedDict,
)
from .benefitdownloadablesproperties import (
    BenefitDownloadablesProperties,
    BenefitDownloadablesPropertiesTypedDict,
)
from .benefitdownloadablessubscriber import (
    BenefitDownloadablesSubscriber,
    BenefitDownloadablesSubscriberTypedDict,
)
from .benefitdownloadablessubscriberproperties import (
    BenefitDownloadablesSubscriberProperties,
    BenefitDownloadablesSubscriberPropertiesTypedDict,
)
from .benefitdownloadablesupdate import (
    BenefitDownloadablesUpdate,
    BenefitDownloadablesUpdateTypedDict,
)
from .benefitgithubrepository import (
    BenefitGitHubRepository,
    BenefitGitHubRepositoryTypedDict,
)
from .benefitgithubrepositorycreate import (
    BenefitGitHubRepositoryCreate,
    BenefitGitHubRepositoryCreateTypedDict,
)
from .benefitgithubrepositorycreateproperties import (
    BenefitGitHubRepositoryCreateProperties,
    BenefitGitHubRepositoryCreatePropertiesPermission,
    BenefitGitHubRepositoryCreatePropertiesTypedDict,
)
from .benefitgithubrepositoryproperties import (
    BenefitGitHubRepositoryProperties,
    BenefitGitHubRepositoryPropertiesTypedDict,
    Permission,
)
from .benefitgithubrepositorysubscriber import (
    BenefitGitHubRepositorySubscriber,
    BenefitGitHubRepositorySubscriberTypedDict,
)
from .benefitgithubrepositorysubscriberproperties import (
    BenefitGitHubRepositorySubscriberProperties,
    BenefitGitHubRepositorySubscriberPropertiesTypedDict,
)
from .benefitgithubrepositoryupdate import (
    BenefitGitHubRepositoryUpdate,
    BenefitGitHubRepositoryUpdateTypedDict,
)
from .benefitgrant import (
    BenefitGrant,
    BenefitGrantTypedDict,
    Properties,
    PropertiesTypedDict,
)
from .benefitgrantcustomproperties import (
    BenefitGrantCustomProperties,
    BenefitGrantCustomPropertiesTypedDict,
)
from .benefitgrantdiscordproperties import (
    BenefitGrantDiscordProperties,
    BenefitGrantDiscordPropertiesTypedDict,
)
from .benefitgrantdownloadablesproperties import (
    BenefitGrantDownloadablesProperties,
    BenefitGrantDownloadablesPropertiesTypedDict,
)
from .benefitgrantgithubrepositoryproperties import (
    BenefitGrantGitHubRepositoryProperties,
    BenefitGrantGitHubRepositoryPropertiesPermission,
    BenefitGrantGitHubRepositoryPropertiesTypedDict,
)
from .benefitgrantlicensekeysproperties import (
    BenefitGrantLicenseKeysProperties,
    BenefitGrantLicenseKeysPropertiesTypedDict,
)
from .benefitgrantwebhook import (
    BenefitGrantWebhook,
    BenefitGrantWebhookProperties,
    BenefitGrantWebhookPropertiesTypedDict,
    BenefitGrantWebhookTypedDict,
    PreviousProperties,
    PreviousPropertiesTypedDict,
)
from .benefitlicensekeyactivationproperties import (
    BenefitLicenseKeyActivationProperties,
    BenefitLicenseKeyActivationPropertiesTypedDict,
)
from .benefitlicensekeyexpirationproperties import (
    BenefitLicenseKeyExpirationProperties,
    BenefitLicenseKeyExpirationPropertiesTypedDict,
    Timeframe,
)
from .benefitlicensekeys import BenefitLicenseKeys, BenefitLicenseKeysTypedDict
from .benefitlicensekeyscreate import (
    BenefitLicenseKeysCreate,
    BenefitLicenseKeysCreateTypedDict,
)
from .benefitlicensekeyscreateproperties import (
    BenefitLicenseKeysCreateProperties,
    BenefitLicenseKeysCreatePropertiesTypedDict,
)
from .benefitlicensekeysproperties import (
    BenefitLicenseKeysProperties,
    BenefitLicenseKeysPropertiesTypedDict,
)
from .benefitlicensekeyssubscriber import (
    BenefitLicenseKeysSubscriber,
    BenefitLicenseKeysSubscriberTypedDict,
)
from .benefitlicensekeyssubscriberproperties import (
    BenefitLicenseKeysSubscriberProperties,
    BenefitLicenseKeysSubscriberPropertiesTypedDict,
)
from .benefitlicensekeysupdate import (
    BenefitLicenseKeysUpdate,
    BenefitLicenseKeysUpdateTypedDict,
)
from .benefits_deleteop import BenefitsDeleteRequest, BenefitsDeleteRequestTypedDict
from .benefits_getop import BenefitsGetRequest, BenefitsGetRequestTypedDict
from .benefits_grantsop import (
    BenefitsGrantsRequest,
    BenefitsGrantsRequestTypedDict,
    BenefitsGrantsResponse,
    BenefitsGrantsResponseTypedDict,
    QueryParamCustomerIDFilter,
    QueryParamCustomerIDFilterTypedDict,
)
from .benefits_listop import (
    BenefitTypeFilter,
    BenefitTypeFilterTypedDict,
    BenefitsListQueryParamOrganizationIDFilter,
    BenefitsListQueryParamOrganizationIDFilterTypedDict,
    BenefitsListRequest,
    BenefitsListRequestTypedDict,
    BenefitsListResponse,
    BenefitsListResponseTypedDict,
)
from .benefits_updateop import (
    BenefitsUpdateBenefitUpdate,
    BenefitsUpdateBenefitUpdateTypedDict,
    BenefitsUpdateRequest,
    BenefitsUpdateRequestTypedDict,
)
from .benefittype import BenefitType
from .checkout import (
    Checkout,
    CheckoutCustomFieldData,
    CheckoutCustomFieldDataTypedDict,
    CheckoutDiscount,
    CheckoutDiscountTypedDict,
    CheckoutMetadata,
    CheckoutMetadataTypedDict,
    CheckoutProductPrice,
    CheckoutProductPriceTypedDict,
    CheckoutTypedDict,
    CustomerMetadata,
    CustomerMetadataTypedDict,
)
from .checkout_links_createop import (
    CheckoutLinksCreateCheckoutLinkCreate,
    CheckoutLinksCreateCheckoutLinkCreateTypedDict,
)
from .checkout_links_deleteop import (
    CheckoutLinksDeleteRequest,
    CheckoutLinksDeleteRequestTypedDict,
)
from .checkout_links_getop import (
    CheckoutLinksGetRequest,
    CheckoutLinksGetRequestTypedDict,
)
from .checkout_links_listop import (
    CheckoutLinksListQueryParamOrganizationIDFilter,
    CheckoutLinksListQueryParamOrganizationIDFilterTypedDict,
    CheckoutLinksListQueryParamProductIDFilter,
    CheckoutLinksListQueryParamProductIDFilterTypedDict,
    CheckoutLinksListRequest,
    CheckoutLinksListRequestTypedDict,
    CheckoutLinksListResponse,
    CheckoutLinksListResponseTypedDict,
)
from .checkout_links_updateop import (
    CheckoutLinksUpdateRequest,
    CheckoutLinksUpdateRequestTypedDict,
)
from .checkoutconfirmstripe import (
    CheckoutConfirmStripe,
    CheckoutConfirmStripeCustomFieldData,
    CheckoutConfirmStripeCustomFieldDataTypedDict,
    CheckoutConfirmStripeTypedDict,
)
from .checkoutcreate import CheckoutCreate, CheckoutCreateTypedDict
from .checkoutdiscountfixedonceforeverduration import (
    CheckoutDiscountFixedOnceForeverDuration,
    CheckoutDiscountFixedOnceForeverDurationTypedDict,
)
from .checkoutdiscountfixedrepeatduration import (
    CheckoutDiscountFixedRepeatDuration,
    CheckoutDiscountFixedRepeatDurationTypedDict,
)
from .checkoutdiscountpercentageonceforeverduration import (
    CheckoutDiscountPercentageOnceForeverDuration,
    CheckoutDiscountPercentageOnceForeverDurationTypedDict,
)
from .checkoutdiscountpercentagerepeatduration import (
    CheckoutDiscountPercentageRepeatDuration,
    CheckoutDiscountPercentageRepeatDurationTypedDict,
)
from .checkoutforbiddenerror import CheckoutForbiddenError, CheckoutForbiddenErrorUnion
from .checkoutlink import (
    CheckoutLink,
    CheckoutLinkDiscount,
    CheckoutLinkDiscountTypedDict,
    CheckoutLinkMetadata,
    CheckoutLinkMetadataTypedDict,
    CheckoutLinkProductPrice,
    CheckoutLinkProductPriceTypedDict,
    CheckoutLinkTypedDict,
)
from .checkoutlinkcreateproduct import (
    CheckoutLinkCreateProduct,
    CheckoutLinkCreateProductMetadata,
    CheckoutLinkCreateProductMetadataTypedDict,
    CheckoutLinkCreateProductTypedDict,
)
from .checkoutlinkcreateproductprice import (
    CheckoutLinkCreateProductPrice,
    CheckoutLinkCreateProductPriceMetadata,
    CheckoutLinkCreateProductPriceMetadataTypedDict,
    CheckoutLinkCreateProductPriceTypedDict,
)
from .checkoutlinkcreateproducts import (
    CheckoutLinkCreateProducts,
    CheckoutLinkCreateProductsMetadata,
    CheckoutLinkCreateProductsMetadataTypedDict,
    CheckoutLinkCreateProductsTypedDict,
)
from .checkoutlinkproduct import (
    CheckoutLinkProduct,
    CheckoutLinkProductPrices,
    CheckoutLinkProductPricesTypedDict,
    CheckoutLinkProductTypedDict,
)
from .checkoutlinksortproperty import CheckoutLinkSortProperty
from .checkoutlinkupdate import (
    CheckoutLinkUpdate,
    CheckoutLinkUpdateMetadata,
    CheckoutLinkUpdateMetadataTypedDict,
    CheckoutLinkUpdateTypedDict,
)
from .checkoutpricecreate import (
    CheckoutPriceCreate,
    CheckoutPriceCreateCustomFieldData,
    CheckoutPriceCreateCustomFieldDataTypedDict,
    CheckoutPriceCreateCustomerMetadata,
    CheckoutPriceCreateCustomerMetadataTypedDict,
    CheckoutPriceCreateMetadata,
    CheckoutPriceCreateMetadataTypedDict,
    CheckoutPriceCreateTypedDict,
)
from .checkoutproduct import (
    CheckoutProduct,
    CheckoutProductPrices,
    CheckoutProductPricesTypedDict,
    CheckoutProductTypedDict,
)
from .checkoutproductcreate import (
    CheckoutProductCreate,
    CheckoutProductCreateCustomFieldData,
    CheckoutProductCreateCustomFieldDataTypedDict,
    CheckoutProductCreateCustomerMetadata,
    CheckoutProductCreateCustomerMetadataTypedDict,
    CheckoutProductCreateMetadata,
    CheckoutProductCreateMetadataTypedDict,
    CheckoutProductCreateTypedDict,
)
from .checkoutproductscreate import (
    CheckoutProductsCreate,
    CheckoutProductsCreateCustomFieldData,
    CheckoutProductsCreateCustomFieldDataTypedDict,
    CheckoutProductsCreateCustomerMetadata,
    CheckoutProductsCreateCustomerMetadataTypedDict,
    CheckoutProductsCreateMetadata,
    CheckoutProductsCreateMetadataTypedDict,
    CheckoutProductsCreateTypedDict,
)
from .checkoutpublic import (
    CheckoutPublic,
    CheckoutPublicCustomFieldData,
    CheckoutPublicCustomFieldDataTypedDict,
    CheckoutPublicDiscount,
    CheckoutPublicDiscountTypedDict,
    CheckoutPublicProductPrice,
    CheckoutPublicProductPriceTypedDict,
    CheckoutPublicTypedDict,
)
from .checkoutpublicconfirmed import (
    CheckoutPublicConfirmed,
    CheckoutPublicConfirmedCustomFieldData,
    CheckoutPublicConfirmedCustomFieldDataTypedDict,
    CheckoutPublicConfirmedDiscount,
    CheckoutPublicConfirmedDiscountTypedDict,
    CheckoutPublicConfirmedProductPrice,
    CheckoutPublicConfirmedProductPriceTypedDict,
    CheckoutPublicConfirmedTypedDict,
)
from .checkouts_client_confirmop import (
    CheckoutsClientConfirmRequest,
    CheckoutsClientConfirmRequestTypedDict,
)
from .checkouts_client_getop import (
    CheckoutsClientGetRequest,
    CheckoutsClientGetRequestTypedDict,
)
from .checkouts_client_updateop import (
    CheckoutsClientUpdateRequest,
    CheckoutsClientUpdateRequestTypedDict,
)
from .checkouts_getop import CheckoutsGetRequest, CheckoutsGetRequestTypedDict
from .checkouts_listop import (
    CheckoutsListQueryParamOrganizationIDFilter,
    CheckoutsListQueryParamOrganizationIDFilterTypedDict,
    CheckoutsListQueryParamProductIDFilter,
    CheckoutsListQueryParamProductIDFilterTypedDict,
    CheckoutsListRequest,
    CheckoutsListRequestTypedDict,
    CheckoutsListResponse,
    CheckoutsListResponseTypedDict,
)
from .checkouts_updateop import CheckoutsUpdateRequest, CheckoutsUpdateRequestTypedDict
from .checkoutsortproperty import CheckoutSortProperty
from .checkoutstatus import CheckoutStatus
from .checkoutupdate import (
    CheckoutUpdate,
    CheckoutUpdateCustomFieldData,
    CheckoutUpdateCustomFieldDataTypedDict,
    CheckoutUpdateCustomerMetadata,
    CheckoutUpdateCustomerMetadataTypedDict,
    CheckoutUpdateMetadata,
    CheckoutUpdateMetadataTypedDict,
    CheckoutUpdateTypedDict,
)
from .checkoutupdatepublic import (
    CheckoutUpdatePublic,
    CheckoutUpdatePublicCustomFieldData,
    CheckoutUpdatePublicCustomFieldDataTypedDict,
    CheckoutUpdatePublicTypedDict,
)
from .countaggregation import CountAggregation, CountAggregationTypedDict
from .currencyamount import CurrencyAmount, CurrencyAmountTypedDict
from .custom_fields_deleteop import (
    CustomFieldsDeleteRequest,
    CustomFieldsDeleteRequestTypedDict,
)
from .custom_fields_getop import CustomFieldsGetRequest, CustomFieldsGetRequestTypedDict
from .custom_fields_listop import (
    CustomFieldTypeFilter,
    CustomFieldTypeFilterTypedDict,
    CustomFieldsListQueryParamOrganizationIDFilter,
    CustomFieldsListQueryParamOrganizationIDFilterTypedDict,
    CustomFieldsListRequest,
    CustomFieldsListRequestTypedDict,
    CustomFieldsListResponse,
    CustomFieldsListResponseTypedDict,
)
from .custom_fields_updateop import (
    CustomFieldsUpdateRequest,
    CustomFieldsUpdateRequestTypedDict,
)
from .customer import (
    Customer,
    CustomerMetadata1,
    CustomerMetadata1TypedDict,
    CustomerTaxID,
    CustomerTaxIDTypedDict,
    CustomerTypedDict,
)
from .customer_portal_benefit_grants_getop import (
    CustomerPortalBenefitGrantsGetRequest,
    CustomerPortalBenefitGrantsGetRequestTypedDict,
    CustomerPortalBenefitGrantsGetSecurity,
    CustomerPortalBenefitGrantsGetSecurityTypedDict,
)
from .customer_portal_benefit_grants_listop import (
    CustomerPortalBenefitGrantsListQueryParamBenefitIDFilter,
    CustomerPortalBenefitGrantsListQueryParamBenefitIDFilterTypedDict,
    CustomerPortalBenefitGrantsListQueryParamOrganizationIDFilter,
    CustomerPortalBenefitGrantsListQueryParamOrganizationIDFilterTypedDict,
    CustomerPortalBenefitGrantsListRequest,
    CustomerPortalBenefitGrantsListRequestTypedDict,
    CustomerPortalBenefitGrantsListResponse,
    CustomerPortalBenefitGrantsListResponseTypedDict,
    CustomerPortalBenefitGrantsListSecurity,
    CustomerPortalBenefitGrantsListSecurityTypedDict,
    QueryParamBenefitTypeFilter,
    QueryParamBenefitTypeFilterTypedDict,
    QueryParamCheckoutIDFilter,
    QueryParamCheckoutIDFilterTypedDict,
    QueryParamOrderIDFilter,
    QueryParamOrderIDFilterTypedDict,
    QueryParamSubscriptionIDFilter,
    QueryParamSubscriptionIDFilterTypedDict,
)
from .customer_portal_benefit_grants_updateop import (
    CustomerPortalBenefitGrantsUpdateRequest,
    CustomerPortalBenefitGrantsUpdateRequestTypedDict,
    CustomerPortalBenefitGrantsUpdateSecurity,
    CustomerPortalBenefitGrantsUpdateSecurityTypedDict,
)
from .customer_portal_customers_add_payment_methodop import (
    CustomerPortalCustomersAddPaymentMethodResponseCustomerPortalCustomersAddPaymentMethod,
    CustomerPortalCustomersAddPaymentMethodResponseCustomerPortalCustomersAddPaymentMethodTypedDict,
    CustomerPortalCustomersAddPaymentMethodSecurity,
    CustomerPortalCustomersAddPaymentMethodSecurityTypedDict,
)
from .customer_portal_customers_delete_payment_methodop import (
    CustomerPortalCustomersDeletePaymentMethodRequest,
    CustomerPortalCustomersDeletePaymentMethodRequestTypedDict,
    CustomerPortalCustomersDeletePaymentMethodSecurity,
    CustomerPortalCustomersDeletePaymentMethodSecurityTypedDict,
)
from .customer_portal_customers_get_payment_methodsop import (
    CustomerPortalCustomersGetPaymentMethodsRequest,
    CustomerPortalCustomersGetPaymentMethodsRequestTypedDict,
    CustomerPortalCustomersGetPaymentMethodsResponse,
    CustomerPortalCustomersGetPaymentMethodsResponseTypedDict,
    CustomerPortalCustomersGetPaymentMethodsSecurity,
    CustomerPortalCustomersGetPaymentMethodsSecurityTypedDict,
)
from .customer_portal_customers_getop import (
    CustomerPortalCustomersGetSecurity,
    CustomerPortalCustomersGetSecurityTypedDict,
)
from .customer_portal_customers_updateop import (
    CustomerPortalCustomersUpdateSecurity,
    CustomerPortalCustomersUpdateSecurityTypedDict,
)
from .customer_portal_downloadables_customer_portal_downloadables_getop import (
    CustomerPortalDownloadablesCustomerPortalDownloadablesGetRequest,
    CustomerPortalDownloadablesCustomerPortalDownloadablesGetRequestTypedDict,
)
from .customer_portal_downloadables_listop import (
    CustomerPortalDownloadablesListQueryParamBenefitIDFilter,
    CustomerPortalDownloadablesListQueryParamBenefitIDFilterTypedDict,
    CustomerPortalDownloadablesListQueryParamOrganizationIDFilter,
    CustomerPortalDownloadablesListQueryParamOrganizationIDFilterTypedDict,
    CustomerPortalDownloadablesListRequest,
    CustomerPortalDownloadablesListRequestTypedDict,
    CustomerPortalDownloadablesListResponse,
    CustomerPortalDownloadablesListResponseTypedDict,
    CustomerPortalDownloadablesListSecurity,
    CustomerPortalDownloadablesListSecurityTypedDict,
)
from .customer_portal_license_keys_getop import (
    CustomerPortalLicenseKeysGetRequest,
    CustomerPortalLicenseKeysGetRequestTypedDict,
    CustomerPortalLicenseKeysGetSecurity,
    CustomerPortalLicenseKeysGetSecurityTypedDict,
)
from .customer_portal_license_keys_listop import (
    CustomerPortalLicenseKeysListQueryParamOrganizationIDFilter,
    CustomerPortalLicenseKeysListQueryParamOrganizationIDFilterTypedDict,
    CustomerPortalLicenseKeysListRequest,
    CustomerPortalLicenseKeysListRequestTypedDict,
    CustomerPortalLicenseKeysListResponse,
    CustomerPortalLicenseKeysListResponseTypedDict,
    CustomerPortalLicenseKeysListSecurity,
    CustomerPortalLicenseKeysListSecurityTypedDict,
)
from .customer_portal_orders_getop import (
    CustomerPortalOrdersGetRequest,
    CustomerPortalOrdersGetRequestTypedDict,
    CustomerPortalOrdersGetSecurity,
    CustomerPortalOrdersGetSecurityTypedDict,
)
from .customer_portal_orders_invoiceop import (
    CustomerPortalOrdersInvoiceRequest,
    CustomerPortalOrdersInvoiceRequestTypedDict,
    CustomerPortalOrdersInvoiceSecurity,
    CustomerPortalOrdersInvoiceSecurityTypedDict,
)
from .customer_portal_orders_listop import (
    CustomerPortalOrdersListQueryParamOrganizationIDFilter,
    CustomerPortalOrdersListQueryParamOrganizationIDFilterTypedDict,
    CustomerPortalOrdersListQueryParamProductBillingTypeFilter,
    CustomerPortalOrdersListQueryParamProductBillingTypeFilterTypedDict,
    CustomerPortalOrdersListQueryParamProductIDFilter,
    CustomerPortalOrdersListQueryParamProductIDFilterTypedDict,
    CustomerPortalOrdersListQueryParamSubscriptionIDFilter,
    CustomerPortalOrdersListQueryParamSubscriptionIDFilterTypedDict,
    CustomerPortalOrdersListRequest,
    CustomerPortalOrdersListRequestTypedDict,
    CustomerPortalOrdersListResponse,
    CustomerPortalOrdersListResponseTypedDict,
    CustomerPortalOrdersListSecurity,
    CustomerPortalOrdersListSecurityTypedDict,
    QueryParamProductPriceTypeFilter,
    QueryParamProductPriceTypeFilterTypedDict,
)
from .customer_portal_organizations_getop import (
    CustomerPortalOrganizationsGetRequest,
    CustomerPortalOrganizationsGetRequestTypedDict,
)
from .customer_portal_subscriptions_cancelop import (
    CustomerPortalSubscriptionsCancelRequest,
    CustomerPortalSubscriptionsCancelRequestTypedDict,
    CustomerPortalSubscriptionsCancelSecurity,
    CustomerPortalSubscriptionsCancelSecurityTypedDict,
)
from .customer_portal_subscriptions_getop import (
    CustomerPortalSubscriptionsGetRequest,
    CustomerPortalSubscriptionsGetRequestTypedDict,
    CustomerPortalSubscriptionsGetSecurity,
    CustomerPortalSubscriptionsGetSecurityTypedDict,
)
from .customer_portal_subscriptions_listop import (
    CustomerPortalSubscriptionsListQueryParamOrganizationIDFilter,
    CustomerPortalSubscriptionsListQueryParamOrganizationIDFilterTypedDict,
    CustomerPortalSubscriptionsListQueryParamProductIDFilter,
    CustomerPortalSubscriptionsListQueryParamProductIDFilterTypedDict,
    CustomerPortalSubscriptionsListRequest,
    CustomerPortalSubscriptionsListRequestTypedDict,
    CustomerPortalSubscriptionsListResponse,
    CustomerPortalSubscriptionsListResponseTypedDict,
    CustomerPortalSubscriptionsListSecurity,
    CustomerPortalSubscriptionsListSecurityTypedDict,
)
from .customer_portal_subscriptions_updateop import (
    CustomerPortalSubscriptionsUpdateRequest,
    CustomerPortalSubscriptionsUpdateRequestTypedDict,
    CustomerPortalSubscriptionsUpdateSecurity,
    CustomerPortalSubscriptionsUpdateSecurityTypedDict,
)
from .customer_sessions_createop import (
    CustomerSessionsCreateCustomerSessionCreate,
    CustomerSessionsCreateCustomerSessionCreateTypedDict,
)
from .customerbenefitgrant import CustomerBenefitGrant, CustomerBenefitGrantTypedDict
from .customerbenefitgrantcustom import (
    CustomerBenefitGrantCustom,
    CustomerBenefitGrantCustomTypedDict,
)
from .customerbenefitgrantcustomupdate import (
    CustomerBenefitGrantCustomUpdate,
    CustomerBenefitGrantCustomUpdateTypedDict,
)
from .customerbenefitgrantdiscord import (
    CustomerBenefitGrantDiscord,
    CustomerBenefitGrantDiscordTypedDict,
)
from .customerbenefitgrantdiscordpropertiesupdate import (
    CustomerBenefitGrantDiscordPropertiesUpdate,
    CustomerBenefitGrantDiscordPropertiesUpdateTypedDict,
)
from .customerbenefitgrantdiscordupdate import (
    CustomerBenefitGrantDiscordUpdate,
    CustomerBenefitGrantDiscordUpdateTypedDict,
)
from .customerbenefitgrantdownloadables import (
    CustomerBenefitGrantDownloadables,
    CustomerBenefitGrantDownloadablesTypedDict,
)
from .customerbenefitgrantdownloadablesupdate import (
    CustomerBenefitGrantDownloadablesUpdate,
    CustomerBenefitGrantDownloadablesUpdateTypedDict,
)
from .customerbenefitgrantgithubrepository import (
    CustomerBenefitGrantGitHubRepository,
    CustomerBenefitGrantGitHubRepositoryTypedDict,
)
from .customerbenefitgrantgithubrepositorypropertiesupdate import (
    CustomerBenefitGrantGitHubRepositoryPropertiesUpdate,
    CustomerBenefitGrantGitHubRepositoryPropertiesUpdateTypedDict,
)
from .customerbenefitgrantgithubrepositoryupdate import (
    CustomerBenefitGrantGitHubRepositoryUpdate,
    CustomerBenefitGrantGitHubRepositoryUpdateTypedDict,
)
from .customerbenefitgrantlicensekeys import (
    CustomerBenefitGrantLicenseKeys,
    CustomerBenefitGrantLicenseKeysTypedDict,
)
from .customerbenefitgrantlicensekeysupdate import (
    CustomerBenefitGrantLicenseKeysUpdate,
    CustomerBenefitGrantLicenseKeysUpdateTypedDict,
)
from .customerbenefitgrantsortproperty import CustomerBenefitGrantSortProperty
from .customerbenefitgrantupdate import (
    CustomerBenefitGrantUpdate,
    CustomerBenefitGrantUpdateTypedDict,
)
from .customercancellationreason import CustomerCancellationReason
from .customercreate import (
    CustomerCreate,
    CustomerCreateMetadata,
    CustomerCreateMetadataTypedDict,
    CustomerCreateTaxID,
    CustomerCreateTaxIDTypedDict,
    CustomerCreateTypedDict,
)
from .customerorder import (
    CustomerOrder,
    CustomerOrderProductPrice,
    CustomerOrderProductPriceTypedDict,
    CustomerOrderTypedDict,
)
from .customerorderinvoice import CustomerOrderInvoice, CustomerOrderInvoiceTypedDict
from .customerorderproduct import (
    CustomerOrderProduct,
    CustomerOrderProductPrices,
    CustomerOrderProductPricesTypedDict,
    CustomerOrderProductTypedDict,
)
from .customerordersortproperty import CustomerOrderSortProperty
from .customerordersubscription import (
    CustomerOrderSubscription,
    CustomerOrderSubscriptionTypedDict,
)
from .customerorganization import CustomerOrganization, CustomerOrganizationTypedDict
from .customerpaymentmethodcreate import (
    CustomerPaymentMethodCreate,
    CustomerPaymentMethodCreateTypedDict,
)
from .customerportalcustomer import (
    CustomerPortalCustomer,
    CustomerPortalCustomerTaxID,
    CustomerPortalCustomerTaxIDTypedDict,
    CustomerPortalCustomerTypedDict,
)
from .customerportalcustomerupdate import (
    CustomerPortalCustomerUpdate,
    CustomerPortalCustomerUpdateTypedDict,
)
from .customerportaloauthaccount import (
    CustomerPortalOAuthAccount,
    CustomerPortalOAuthAccountTypedDict,
)
from .customerproduct import (
    CustomerProduct,
    CustomerProductPrices,
    CustomerProductPricesTypedDict,
    CustomerProductTypedDict,
)
from .customers_delete_externalop import (
    CustomersDeleteExternalRequest,
    CustomersDeleteExternalRequestTypedDict,
)
from .customers_deleteop import CustomersDeleteRequest, CustomersDeleteRequestTypedDict
from .customers_get_externalop import (
    CustomersGetExternalRequest,
    CustomersGetExternalRequestTypedDict,
)
from .customers_get_state_externalop import (
    CustomersGetStateExternalRequest,
    CustomersGetStateExternalRequestTypedDict,
)
from .customers_get_stateop import (
    CustomersGetStateRequest,
    CustomersGetStateRequestTypedDict,
)
from .customers_getop import CustomersGetRequest, CustomersGetRequestTypedDict
from .customers_listop import (
    CustomersListQueryParamOrganizationIDFilter,
    CustomersListQueryParamOrganizationIDFilterTypedDict,
    CustomersListRequest,
    CustomersListRequestTypedDict,
    CustomersListResponse,
    CustomersListResponseTypedDict,
    EventsListQueryParamCustomerIDFilter,
    EventsListQueryParamCustomerIDFilterTypedDict,
    EventsListQueryParamOrganizationIDFilter,
    EventsListQueryParamOrganizationIDFilterTypedDict,
    EventsListRequest,
    EventsListRequestTypedDict,
    EventsListResponse,
    EventsListResponseTypedDict,
    ExternalCustomerIDFilter,
    ExternalCustomerIDFilterTypedDict,
    MetadataQuery,
    MetadataQueryTypedDict,
    MetersListQueryParamOrganizationIDFilter,
    MetersListQueryParamOrganizationIDFilterTypedDict,
    MetersListRequest,
    MetersListRequestTypedDict,
    MetersListResponse,
    MetersListResponseTypedDict,
    SourceFilter,
    SourceFilterTypedDict,
)
from .customers_update_externalop import (
    CustomersUpdateExternalRequest,
    CustomersUpdateExternalRequestTypedDict,
)
from .customers_updateop import CustomersUpdateRequest, CustomersUpdateRequestTypedDict
from .customersession import CustomerSession, CustomerSessionTypedDict
from .customersessioncustomerexternalidcreate import (
    CustomerSessionCustomerExternalIDCreate,
    CustomerSessionCustomerExternalIDCreateTypedDict,
)
from .customersessioncustomeridcreate import (
    CustomerSessionCustomerIDCreate,
    CustomerSessionCustomerIDCreateTypedDict,
)
from .customersortproperty import CustomerSortProperty
from .customerstate import (
    CustomerState,
    CustomerStateMetadata,
    CustomerStateMetadataTypedDict,
    CustomerStateTaxID,
    CustomerStateTaxIDTypedDict,
    CustomerStateTypedDict,
)
from .customerstatebenefitgrant import (
    CustomerStateBenefitGrant,
    CustomerStateBenefitGrantProperties,
    CustomerStateBenefitGrantPropertiesTypedDict,
    CustomerStateBenefitGrantTypedDict,
)
from .customerstatesubscription import (
    CustomerStateSubscription,
    CustomerStateSubscriptionCustomFieldData,
    CustomerStateSubscriptionCustomFieldDataTypedDict,
    CustomerStateSubscriptionMetadata,
    CustomerStateSubscriptionMetadataTypedDict,
    CustomerStateSubscriptionTypedDict,
)
from .customersubscription import (
    CustomerSubscription,
    CustomerSubscriptionPrice,
    CustomerSubscriptionPriceTypedDict,
    CustomerSubscriptionPrices,
    CustomerSubscriptionPricesTypedDict,
    CustomerSubscriptionTypedDict,
)
from .customersubscriptioncancel import (
    CustomerSubscriptionCancel,
    CustomerSubscriptionCancelTypedDict,
)
from .customersubscriptionproduct import (
    CustomerSubscriptionProduct,
    CustomerSubscriptionProductPrices,
    CustomerSubscriptionProductPricesTypedDict,
    CustomerSubscriptionProductTypedDict,
)
from .customersubscriptionsortproperty import CustomerSubscriptionSortProperty
from .customersubscriptionupdate import (
    CustomerSubscriptionUpdate,
    CustomerSubscriptionUpdateTypedDict,
)
from .customersubscriptionupdateproduct import (
    CustomerSubscriptionUpdateProduct,
    CustomerSubscriptionUpdateProductTypedDict,
)
from .customerupdate import (
    CustomerUpdate,
    CustomerUpdateMetadata,
    CustomerUpdateMetadataTypedDict,
    CustomerUpdateTaxID,
    CustomerUpdateTaxIDTypedDict,
    CustomerUpdateTypedDict,
)
from .customfield import CustomField, CustomFieldTypedDict
from .customfieldcheckbox import (
    CustomFieldCheckbox,
    CustomFieldCheckboxMetadata,
    CustomFieldCheckboxMetadataTypedDict,
    CustomFieldCheckboxTypedDict,
)
from .customfieldcheckboxproperties import (
    CustomFieldCheckboxProperties,
    CustomFieldCheckboxPropertiesTypedDict,
)
from .customfieldcreate import CustomFieldCreate, CustomFieldCreateTypedDict
from .customfieldcreatecheckbox import (
    CustomFieldCreateCheckbox,
    CustomFieldCreateCheckboxMetadata,
    CustomFieldCreateCheckboxMetadataTypedDict,
    CustomFieldCreateCheckboxTypedDict,
)
from .customfieldcreatedate import (
    CustomFieldCreateDate,
    CustomFieldCreateDateMetadata,
    CustomFieldCreateDateMetadataTypedDict,
    CustomFieldCreateDateTypedDict,
)
from .customfieldcreatenumber import (
    CustomFieldCreateNumber,
    CustomFieldCreateNumberMetadata,
    CustomFieldCreateNumberMetadataTypedDict,
    CustomFieldCreateNumberTypedDict,
)
from .customfieldcreateselect import (
    CustomFieldCreateSelect,
    CustomFieldCreateSelectMetadata,
    CustomFieldCreateSelectMetadataTypedDict,
    CustomFieldCreateSelectTypedDict,
)
from .customfieldcreatetext import (
    CustomFieldCreateText,
    CustomFieldCreateTextMetadata,
    CustomFieldCreateTextMetadataTypedDict,
    CustomFieldCreateTextTypedDict,
)
from .customfielddate import (
    CustomFieldDate,
    CustomFieldDateMetadata,
    CustomFieldDateMetadataTypedDict,
    CustomFieldDateTypedDict,
)
from .customfielddateproperties import (
    CustomFieldDateProperties,
    CustomFieldDatePropertiesTypedDict,
)
from .customfieldnumber import (
    CustomFieldNumber,
    CustomFieldNumberMetadata,
    CustomFieldNumberMetadataTypedDict,
    CustomFieldNumberTypedDict,
)
from .customfieldnumberproperties import (
    CustomFieldNumberProperties,
    CustomFieldNumberPropertiesTypedDict,
)
from .customfieldselect import (
    CustomFieldSelect,
    CustomFieldSelectMetadata,
    CustomFieldSelectMetadataTypedDict,
    CustomFieldSelectTypedDict,
)
from .customfieldselectoption import (
    CustomFieldSelectOption,
    CustomFieldSelectOptionTypedDict,
)
from .customfieldselectproperties import (
    CustomFieldSelectProperties,
    CustomFieldSelectPropertiesTypedDict,
)
from .customfieldsortproperty import CustomFieldSortProperty
from .customfieldtext import (
    CustomFieldText,
    CustomFieldTextMetadata,
    CustomFieldTextMetadataTypedDict,
    CustomFieldTextTypedDict,
)
from .customfieldtextproperties import (
    CustomFieldTextProperties,
    CustomFieldTextPropertiesTypedDict,
)
from .customfieldtype import CustomFieldType
from .customfieldupdate import CustomFieldUpdate, CustomFieldUpdateTypedDict
from .customfieldupdatecheckbox import (
    CustomFieldUpdateCheckbox,
    CustomFieldUpdateCheckboxMetadata,
    CustomFieldUpdateCheckboxMetadataTypedDict,
    CustomFieldUpdateCheckboxTypedDict,
)
from .customfieldupdatedate import (
    CustomFieldUpdateDate,
    CustomFieldUpdateDateMetadata,
    CustomFieldUpdateDateMetadataTypedDict,
    CustomFieldUpdateDateTypedDict,
)
from .customfieldupdatenumber import (
    CustomFieldUpdateNumber,
    CustomFieldUpdateNumberMetadata,
    CustomFieldUpdateNumberMetadataTypedDict,
    CustomFieldUpdateNumberTypedDict,
)
from .customfieldupdateselect import (
    CustomFieldUpdateSelect,
    CustomFieldUpdateSelectMetadata,
    CustomFieldUpdateSelectMetadataTypedDict,
    CustomFieldUpdateSelectTypedDict,
)
from .customfieldupdatetext import (
    CustomFieldUpdateText,
    CustomFieldUpdateTextMetadata,
    CustomFieldUpdateTextMetadataTypedDict,
    CustomFieldUpdateTextTypedDict,
)
from .discount import Discount, DiscountTypedDict
from .discountcreate import DiscountCreate, DiscountCreateTypedDict
from .discountduration import DiscountDuration
from .discountfixedonceforeverduration import (
    DiscountFixedOnceForeverDuration,
    DiscountFixedOnceForeverDurationMetadata,
    DiscountFixedOnceForeverDurationMetadataTypedDict,
    DiscountFixedOnceForeverDurationTypedDict,
)
from .discountfixedonceforeverdurationbase import (
    DiscountFixedOnceForeverDurationBase,
    DiscountFixedOnceForeverDurationBaseMetadata,
    DiscountFixedOnceForeverDurationBaseMetadataTypedDict,
    DiscountFixedOnceForeverDurationBaseTypedDict,
)
from .discountfixedonceforeverdurationcreate import (
    DiscountFixedOnceForeverDurationCreate,
    DiscountFixedOnceForeverDurationCreateMetadata,
    DiscountFixedOnceForeverDurationCreateMetadataTypedDict,
    DiscountFixedOnceForeverDurationCreateTypedDict,
)
from .discountfixedrepeatduration import (
    DiscountFixedRepeatDuration,
    DiscountFixedRepeatDurationMetadata,
    DiscountFixedRepeatDurationMetadataTypedDict,
    DiscountFixedRepeatDurationTypedDict,
)
from .discountfixedrepeatdurationbase import (
    DiscountFixedRepeatDurationBase,
    DiscountFixedRepeatDurationBaseMetadata,
    DiscountFixedRepeatDurationBaseMetadataTypedDict,
    DiscountFixedRepeatDurationBaseTypedDict,
)
from .discountfixedrepeatdurationcreate import (
    DiscountFixedRepeatDurationCreate,
    DiscountFixedRepeatDurationCreateMetadata,
    DiscountFixedRepeatDurationCreateMetadataTypedDict,
    DiscountFixedRepeatDurationCreateTypedDict,
)
from .discountpercentageonceforeverduration import (
    DiscountPercentageOnceForeverDuration,
    DiscountPercentageOnceForeverDurationMetadata,
    DiscountPercentageOnceForeverDurationMetadataTypedDict,
    DiscountPercentageOnceForeverDurationTypedDict,
)
from .discountpercentageonceforeverdurationbase import (
    DiscountPercentageOnceForeverDurationBase,
    DiscountPercentageOnceForeverDurationBaseMetadata,
    DiscountPercentageOnceForeverDurationBaseMetadataTypedDict,
    DiscountPercentageOnceForeverDurationBaseTypedDict,
)
from .discountpercentageonceforeverdurationcreate import (
    DiscountPercentageOnceForeverDurationCreate,
    DiscountPercentageOnceForeverDurationCreateMetadata,
    DiscountPercentageOnceForeverDurationCreateMetadataTypedDict,
    DiscountPercentageOnceForeverDurationCreateTypedDict,
)
from .discountpercentagerepeatduration import (
    DiscountPercentageRepeatDuration,
    DiscountPercentageRepeatDurationMetadata,
    DiscountPercentageRepeatDurationMetadataTypedDict,
    DiscountPercentageRepeatDurationTypedDict,
)
from .discountpercentagerepeatdurationbase import (
    DiscountPercentageRepeatDurationBase,
    DiscountPercentageRepeatDurationBaseMetadata,
    DiscountPercentageRepeatDurationBaseMetadataTypedDict,
    DiscountPercentageRepeatDurationBaseTypedDict,
)
from .discountpercentagerepeatdurationcreate import (
    DiscountPercentageRepeatDurationCreate,
    DiscountPercentageRepeatDurationCreateMetadata,
    DiscountPercentageRepeatDurationCreateMetadataTypedDict,
    DiscountPercentageRepeatDurationCreateTypedDict,
)
from .discountproduct import DiscountProduct, DiscountProductTypedDict
from .discounts_deleteop import DiscountsDeleteRequest, DiscountsDeleteRequestTypedDict
from .discounts_getop import DiscountsGetRequest, DiscountsGetRequestTypedDict
from .discounts_listop import (
    DiscountsListQueryParamOrganizationIDFilter,
    DiscountsListQueryParamOrganizationIDFilterTypedDict,
    DiscountsListRequest,
    DiscountsListRequestTypedDict,
    DiscountsListResponse,
    DiscountsListResponseTypedDict,
)
from .discounts_updateop import DiscountsUpdateRequest, DiscountsUpdateRequestTypedDict
from .discountsortproperty import DiscountSortProperty
from .discounttype import DiscountType
from .discountupdate import (
    DiscountUpdate,
    DiscountUpdateMetadata,
    DiscountUpdateMetadataTypedDict,
    DiscountUpdateTypedDict,
)
from .downloadablefilecreate import (
    DownloadableFileCreate,
    DownloadableFileCreateTypedDict,
)
from .downloadablefileread import DownloadableFileRead, DownloadableFileReadTypedDict
from .downloadableread import DownloadableRead, DownloadableReadTypedDict
from .event import Event, EventMetadata, EventMetadataTypedDict, EventTypedDict
from .eventcreatecustomer import (
    EventCreateCustomer,
    EventCreateCustomerMetadata,
    EventCreateCustomerMetadataTypedDict,
    EventCreateCustomerTypedDict,
)
from .eventcreateexternalcustomer import (
    EventCreateExternalCustomer,
    EventCreateExternalCustomerMetadata,
    EventCreateExternalCustomerMetadataTypedDict,
    EventCreateExternalCustomerTypedDict,
)
from .events_getop import EventsGetRequest, EventsGetRequestTypedDict
from .eventsingest import (
    EventsIngest,
    EventsIngestTypedDict,
    EventsModel,
    EventsModelTypedDict,
)
from .eventsingestresponse import EventsIngestResponse, EventsIngestResponseTypedDict
from .eventsortproperty import EventSortProperty
from .eventsource import EventSource
from .existingproductprice import ExistingProductPrice, ExistingProductPriceTypedDict
from .external_organizations_listop import (
    ExternalOrganizationsListRequest,
    ExternalOrganizationsListRequestTypedDict,
    ExternalOrganizationsListResponse,
    ExternalOrganizationsListResponseTypedDict,
    OrganizationIDFilter,
    OrganizationIDFilterTypedDict,
    PlatformFilter,
    PlatformFilterTypedDict,
    RepositoryNameFilter,
    RepositoryNameFilterTypedDict,
)
from .externalorganization import ExternalOrganization, ExternalOrganizationTypedDict
from .externalorganizationsortproperty import ExternalOrganizationSortProperty
from .filecreate import FileCreate, FileCreateTypedDict
from .filedownload import FileDownload, FileDownloadTypedDict
from .filepatch import FilePatch, FilePatchTypedDict
from .files_deleteop import FilesDeleteRequest, FilesDeleteRequestTypedDict
from .files_listop import (
    FilesListRequest,
    FilesListRequestTypedDict,
    FilesListResponse,
    FilesListResponseTypedDict,
)
from .files_updateop import (
    FilesUpdateRequest,
    FilesUpdateRequestTypedDict,
    FilesUpdateResponseFilesUpdate,
    FilesUpdateResponseFilesUpdateTypedDict,
)
from .files_uploadedop import (
    FilesUploadedRequest,
    FilesUploadedRequestTypedDict,
    FilesUploadedResponseFilesUploaded,
    FilesUploadedResponseFilesUploadedTypedDict,
)
from .fileservicetypes import FileServiceTypes
from .fileupload import FileUpload, FileUploadTypedDict
from .fileuploadcompleted import FileUploadCompleted, FileUploadCompletedTypedDict
from .filter_ import Clauses, ClausesTypedDict, Filter, FilterTypedDict
from .filterclause import FilterClause, FilterClauseTypedDict, Value, ValueTypedDict
from .filterconjunction import FilterConjunction
from .filteroperator import FilterOperator
from .funding import Funding, FundingTypedDict
from .httpvalidationerror import HTTPValidationError, HTTPValidationErrorData
from .introspecttokenrequest import (
    IntrospectTokenRequest,
    IntrospectTokenRequestTokenTypeHint,
    IntrospectTokenRequestTypedDict,
)
from .introspecttokenresponse import (
    IntrospectTokenResponse,
    IntrospectTokenResponseTypedDict,
    TokenType,
)
from .issue import Issue, IssueTypedDict
from .label import Label, LabelTypedDict
from .legacyrecurringproductprice import (
    LegacyRecurringProductPrice,
    LegacyRecurringProductPriceTypedDict,
)
from .legacyrecurringproductpricecustom import (
    LegacyRecurringProductPriceCustom,
    LegacyRecurringProductPriceCustomTypedDict,
)
from .legacyrecurringproductpricefixed import (
    LegacyRecurringProductPriceFixed,
    LegacyRecurringProductPriceFixedTypedDict,
)
from .legacyrecurringproductpricefree import (
    LegacyRecurringProductPriceFree,
    LegacyRecurringProductPriceFreeTypedDict,
)
from .license_keys_get_activationop import (
    LicenseKeysGetActivationRequest,
    LicenseKeysGetActivationRequestTypedDict,
)
from .license_keys_getop import LicenseKeysGetRequest, LicenseKeysGetRequestTypedDict
from .license_keys_listop import (
    LicenseKeysListQueryParamOrganizationIDFilter,
    LicenseKeysListQueryParamOrganizationIDFilterTypedDict,
    LicenseKeysListRequest,
    LicenseKeysListRequestTypedDict,
    LicenseKeysListResponse,
    LicenseKeysListResponseTypedDict,
    QueryParamBenefitIDFilter,
    QueryParamBenefitIDFilterTypedDict,
)
from .license_keys_updateop import (
    LicenseKeysUpdateRequest,
    LicenseKeysUpdateRequestTypedDict,
)
from .licensekeyactivate import (
    LicenseKeyActivate,
    LicenseKeyActivateConditions,
    LicenseKeyActivateConditionsTypedDict,
    LicenseKeyActivateMeta,
    LicenseKeyActivateMetaTypedDict,
    LicenseKeyActivateTypedDict,
)
from .licensekeyactivationbase import (
    LicenseKeyActivationBase,
    LicenseKeyActivationBaseTypedDict,
    Meta,
    MetaTypedDict,
)
from .licensekeyactivationread import (
    LicenseKeyActivationRead,
    LicenseKeyActivationReadMeta,
    LicenseKeyActivationReadMetaTypedDict,
    LicenseKeyActivationReadTypedDict,
)
from .licensekeycustomer import (
    LicenseKeyCustomer,
    LicenseKeyCustomerMetadata,
    LicenseKeyCustomerMetadataTypedDict,
    LicenseKeyCustomerTaxID,
    LicenseKeyCustomerTaxIDTypedDict,
    LicenseKeyCustomerTypedDict,
)
from .licensekeydeactivate import LicenseKeyDeactivate, LicenseKeyDeactivateTypedDict
from .licensekeyread import LicenseKeyRead, LicenseKeyReadTypedDict
from .licensekeystatus import LicenseKeyStatus
from .licensekeyupdate import LicenseKeyUpdate, LicenseKeyUpdateTypedDict
from .licensekeyuser import LicenseKeyUser, LicenseKeyUserTypedDict
from .licensekeyvalidate import (
    Conditions,
    ConditionsTypedDict,
    LicenseKeyValidate,
    LicenseKeyValidateTypedDict,
)
from .licensekeywithactivations import (
    LicenseKeyWithActivations,
    LicenseKeyWithActivationsTypedDict,
)
from .listresource_benefit_ import ListResourceBenefit, ListResourceBenefitTypedDict
from .listresource_benefitgrant_ import (
    ListResourceBenefitGrant,
    ListResourceBenefitGrantTypedDict,
)
from .listresource_checkout_ import ListResourceCheckout, ListResourceCheckoutTypedDict
from .listresource_checkoutlink_ import (
    ListResourceCheckoutLink,
    ListResourceCheckoutLinkTypedDict,
)
from .listresource_customer_ import ListResourceCustomer, ListResourceCustomerTypedDict
from .listresource_customerbenefitgrant_ import (
    ListResourceCustomerBenefitGrant,
    ListResourceCustomerBenefitGrantTypedDict,
)
from .listresource_customerorder_ import (
    ListResourceCustomerOrder,
    ListResourceCustomerOrderTypedDict,
)
from .listresource_customersubscription_ import (
    ListResourceCustomerSubscription,
    ListResourceCustomerSubscriptionTypedDict,
)
from .listresource_customfield_ import (
    ListResourceCustomField,
    ListResourceCustomFieldTypedDict,
)
from .listresource_discount_ import ListResourceDiscount, ListResourceDiscountTypedDict
from .listresource_downloadableread_ import (
    ListResourceDownloadableRead,
    ListResourceDownloadableReadTypedDict,
)
from .listresource_event_ import ListResourceEvent, ListResourceEventTypedDict
from .listresource_externalorganization_ import (
    ListResourceExternalOrganization,
    ListResourceExternalOrganizationTypedDict,
)
from .listresource_fileread_ import (
    FileRead,
    FileReadTypedDict,
    ListResourceFileRead,
    ListResourceFileReadTypedDict,
)
from .listresource_licensekeyread_ import (
    ListResourceLicenseKeyRead,
    ListResourceLicenseKeyReadTypedDict,
)
from .listresource_meter_ import ListResourceMeter, ListResourceMeterTypedDict
from .listresource_oauth2client_ import (
    ListResourceOAuth2Client,
    ListResourceOAuth2ClientTypedDict,
)
from .listresource_order_ import ListResourceOrder, ListResourceOrderTypedDict
from .listresource_organization_ import (
    ListResourceOrganization,
    ListResourceOrganizationTypedDict,
)
from .listresource_product_ import ListResourceProduct, ListResourceProductTypedDict
from .listresource_refund_ import ListResourceRefund, ListResourceRefundTypedDict
from .listresource_repository_ import (
    ListResourceRepository,
    ListResourceRepositoryTypedDict,
)
from .listresource_subscription_ import (
    ListResourceSubscription,
    ListResourceSubscriptionTypedDict,
)
from .listresource_union_paymentmethodcard_paymentmethodgeneric_ import (
    Items,
    ItemsTypedDict,
    ListResourceUnionPaymentMethodCardPaymentMethodGeneric,
    ListResourceUnionPaymentMethodCardPaymentMethodGenericTypedDict,
)
from .meter import (
    Meter,
    MeterAggregation,
    MeterAggregationTypedDict,
    MeterMetadata,
    MeterMetadataTypedDict,
    MeterTypedDict,
)
from .metercreate import (
    MeterCreate,
    MeterCreateAggregation,
    MeterCreateAggregationTypedDict,
    MeterCreateMetadata,
    MeterCreateMetadataTypedDict,
    MeterCreateTypedDict,
)
from .meterquantities import MeterQuantities, MeterQuantitiesTypedDict
from .meterquantity import MeterQuantity, MeterQuantityTypedDict
from .meters_eventsop import (
    MetersEventsRequest,
    MetersEventsRequestTypedDict,
    MetersEventsResponse,
    MetersEventsResponseTypedDict,
)
from .meters_getop import MetersGetRequest, MetersGetRequestTypedDict
from .meters_quantitiesop import (
    MetersQuantitiesQueryParamCustomerIDFilter,
    MetersQuantitiesQueryParamCustomerIDFilterTypedDict,
    MetersQuantitiesRequest,
    MetersQuantitiesRequestTypedDict,
    QueryParamExternalCustomerIDFilter,
    QueryParamExternalCustomerIDFilterTypedDict,
)
from .meters_updateop import MetersUpdateRequest, MetersUpdateRequestTypedDict
from .metersortproperty import MeterSortProperty
from .meterupdate import (
    Aggregation,
    AggregationTypedDict,
    MeterUpdate,
    MeterUpdateMetadata,
    MeterUpdateMetadataTypedDict,
    MeterUpdateTypedDict,
)
from .metric import Metric, MetricTypedDict
from .metricperiod import MetricPeriod, MetricPeriodTypedDict
from .metrics import Metrics, MetricsTypedDict
from .metrics_getop import (
    MetricsGetQueryParamCustomerIDFilter,
    MetricsGetQueryParamCustomerIDFilterTypedDict,
    MetricsGetQueryParamOrganizationIDFilter,
    MetricsGetQueryParamOrganizationIDFilterTypedDict,
    MetricsGetQueryParamProductIDFilter,
    MetricsGetQueryParamProductIDFilterTypedDict,
    MetricsGetRequest,
    MetricsGetRequestTypedDict,
    QueryParamProductBillingTypeFilter,
    QueryParamProductBillingTypeFilterTypedDict,
)
from .metricsintervallimit import MetricsIntervalLimit, MetricsIntervalLimitTypedDict
from .metricsintervalslimits import (
    MetricsIntervalsLimits,
    MetricsIntervalsLimitsTypedDict,
)
from .metricslimits import MetricsLimits, MetricsLimitsTypedDict
from .metricsresponse import MetricsResponse, MetricsResponseTypedDict
from .metrictype import MetricType
from .notopencheckout import NotOpenCheckout, NotOpenCheckoutData
from .notpermitted import NotPermitted, NotPermittedData
from .oauth2_authorizeop import (
    Oauth2AuthorizeResponseOauth2Authorize,
    Oauth2AuthorizeResponseOauth2AuthorizeTypedDict,
)
from .oauth2_clients_listop import (
    Oauth2ClientsListRequest,
    Oauth2ClientsListRequestTypedDict,
    Oauth2ClientsListResponse,
    Oauth2ClientsListResponseTypedDict,
)
from .oauth2_clients_oauth2_delete_clientop import (
    Oauth2ClientsOauth2DeleteClientRequest,
    Oauth2ClientsOauth2DeleteClientRequestTypedDict,
)
from .oauth2_clients_oauth2_get_clientop import (
    Oauth2ClientsOauth2GetClientRequest,
    Oauth2ClientsOauth2GetClientRequestTypedDict,
)
from .oauth2_clients_oauth2_update_clientop import (
    Oauth2ClientsOauth2UpdateClientRequest,
    Oauth2ClientsOauth2UpdateClientRequestTypedDict,
)
from .oauth2_request_tokenop import (
    Oauth2RequestTokenRequestBody,
    Oauth2RequestTokenRequestBodyTypedDict,
)
from .oauth2_userinfoop import (
    Oauth2UserinfoResponseOauth2Userinfo,
    Oauth2UserinfoResponseOauth2UserinfoTypedDict,
)
from .oauth2client import (
    GrantTypes,
    OAuth2Client,
    OAuth2ClientTypedDict,
    TokenEndpointAuthMethod,
)
from .oauth2clientconfiguration import (
    OAuth2ClientConfiguration,
    OAuth2ClientConfigurationGrantTypes,
    OAuth2ClientConfigurationTokenEndpointAuthMethod,
    OAuth2ClientConfigurationTypedDict,
)
from .oauth2clientconfigurationupdate import (
    OAuth2ClientConfigurationUpdate,
    OAuth2ClientConfigurationUpdateGrantTypes,
    OAuth2ClientConfigurationUpdateTokenEndpointAuthMethod,
    OAuth2ClientConfigurationUpdateTypedDict,
)
from .oauth2clientpublic import OAuth2ClientPublic, OAuth2ClientPublicTypedDict
from .order import (
    Order,
    OrderCustomFieldData,
    OrderCustomFieldDataTypedDict,
    OrderDiscount,
    OrderDiscountTypedDict,
    OrderMetadata,
    OrderMetadataTypedDict,
    OrderProductPrice,
    OrderProductPriceTypedDict,
    OrderTypedDict,
)
from .orderbillingreason import OrderBillingReason
from .ordercustomer import (
    OrderCustomer,
    OrderCustomerMetadata,
    OrderCustomerMetadataTypedDict,
    OrderCustomerTaxID,
    OrderCustomerTaxIDTypedDict,
    OrderCustomerTypedDict,
)
from .orderinvoice import OrderInvoice, OrderInvoiceTypedDict
from .orderitemschema import OrderItemSchema, OrderItemSchemaTypedDict
from .orderproduct import OrderProduct, OrderProductTypedDict
from .orders_getop import OrdersGetRequest, OrdersGetRequestTypedDict
from .orders_invoiceop import OrdersInvoiceRequest, OrdersInvoiceRequestTypedDict
from .orders_listop import (
    CheckoutIDFilter,
    CheckoutIDFilterTypedDict,
    OrdersListQueryParamCustomerIDFilter,
    OrdersListQueryParamCustomerIDFilterTypedDict,
    OrdersListQueryParamOrganizationIDFilter,
    OrdersListQueryParamOrganizationIDFilterTypedDict,
    OrdersListQueryParamProductIDFilter,
    OrdersListQueryParamProductIDFilterTypedDict,
    OrdersListRequest,
    OrdersListRequestTypedDict,
    OrdersListResponse,
    OrdersListResponseTypedDict,
    ProductBillingTypeFilter,
    ProductBillingTypeFilterTypedDict,
    ProductPriceTypeFilter,
    ProductPriceTypeFilterTypedDict,
    QueryParamDiscountIDFilter,
    QueryParamDiscountIDFilterTypedDict,
)
from .ordersortproperty import OrderSortProperty
from .orderstatus import OrderStatus
from .ordersubscription import (
    OrderSubscription,
    OrderSubscriptionMetadata,
    OrderSubscriptionMetadataTypedDict,
    OrderSubscriptionTypedDict,
)
from .orderuser import OrderUser, OrderUserTypedDict
from .organization import Organization, OrganizationTypedDict
from .organizationavatarfilecreate import (
    OrganizationAvatarFileCreate,
    OrganizationAvatarFileCreateTypedDict,
)
from .organizationavatarfileread import (
    OrganizationAvatarFileRead,
    OrganizationAvatarFileReadTypedDict,
)
from .organizationcreate import OrganizationCreate, OrganizationCreateTypedDict
from .organizationdetails import (
    OrganizationDetails,
    OrganizationDetailsTypedDict,
    SwitchingFrom,
)
from .organizationfeaturesettings import (
    OrganizationFeatureSettings,
    OrganizationFeatureSettingsTypedDict,
)
from .organizationprofilesettings import (
    OrganizationProfileSettings,
    OrganizationProfileSettingsTypedDict,
)
from .organizations_getop import (
    OrganizationsGetRequest,
    OrganizationsGetRequestTypedDict,
)
from .organizations_listop import (
    OrganizationsListRequest,
    OrganizationsListRequestTypedDict,
    OrganizationsListResponse,
    OrganizationsListResponseTypedDict,
)
from .organizations_updateop import (
    OrganizationsUpdateRequest,
    OrganizationsUpdateRequestTypedDict,
)
from .organizationsociallink import (
    OrganizationSocialLink,
    OrganizationSocialLinkTypedDict,
)
from .organizationsocialplatforms import OrganizationSocialPlatforms
from .organizationsortproperty import OrganizationSortProperty
from .organizationsubscribepromotesettings import (
    OrganizationSubscribePromoteSettings,
    OrganizationSubscribePromoteSettingsTypedDict,
)
from .organizationsubscriptionsettings import (
    OrganizationSubscriptionSettings,
    OrganizationSubscriptionSettingsTypedDict,
)
from .organizationupdate import OrganizationUpdate, OrganizationUpdateTypedDict
from .pagination import Pagination, PaginationTypedDict
from .paymenterror import PaymentError, PaymentErrorData
from .paymentmethodcard import PaymentMethodCard, PaymentMethodCardTypedDict
from .paymentmethodcarddata import PaymentMethodCardData, PaymentMethodCardDataTypedDict
from .paymentmethodgeneric import PaymentMethodGeneric, PaymentMethodGenericTypedDict
from .paymentprocessor import PaymentProcessor
from .platforms import Platforms
from .pledge import Pledge, PledgeTypedDict
from .pledger import Pledger, PledgerTypedDict
from .pledgestate import PledgeState
from .pledgetype import PledgeType
from .product import (
    Prices,
    PricesTypedDict,
    Product,
    ProductMetadata,
    ProductMetadataTypedDict,
    ProductTypedDict,
)
from .productbenefitsupdate import ProductBenefitsUpdate, ProductBenefitsUpdateTypedDict
from .productbillingtype import ProductBillingType
from .productcreate import (
    ProductCreate,
    ProductCreateMetadata,
    ProductCreateMetadataTypedDict,
    ProductCreatePrices,
    ProductCreatePricesTypedDict,
    ProductCreateTypedDict,
)
from .productmediafilecreate import (
    ProductMediaFileCreate,
    ProductMediaFileCreateTypedDict,
)
from .productmediafileread import ProductMediaFileRead, ProductMediaFileReadTypedDict
from .productprice import ProductPrice, ProductPriceTypedDict
from .productpricecustom import ProductPriceCustom, ProductPriceCustomTypedDict
from .productpricecustomcreate import (
    ProductPriceCustomCreate,
    ProductPriceCustomCreateTypedDict,
)
from .productpricefixed import ProductPriceFixed, ProductPriceFixedTypedDict
from .productpricefixedcreate import (
    ProductPriceFixedCreate,
    ProductPriceFixedCreateTypedDict,
)
from .productpricefree import ProductPriceFree, ProductPriceFreeTypedDict
from .productpricefreecreate import (
    ProductPriceFreeCreate,
    ProductPriceFreeCreateTypedDict,
)
from .productpricetype import ProductPriceType
from .products_getop import ProductsGetRequest, ProductsGetRequestTypedDict
from .products_listop import (
    BenefitIDFilter,
    BenefitIDFilterTypedDict,
    ProductsListQueryParamOrganizationIDFilter,
    ProductsListQueryParamOrganizationIDFilterTypedDict,
    ProductsListRequest,
    ProductsListRequestTypedDict,
    ProductsListResponse,
    ProductsListResponseTypedDict,
    QueryParamProductIDFilter,
    QueryParamProductIDFilterTypedDict,
)
from .products_update_benefitsop import (
    ProductsUpdateBenefitsRequest,
    ProductsUpdateBenefitsRequestTypedDict,
)
from .products_updateop import ProductsUpdateRequest, ProductsUpdateRequestTypedDict
from .productsortproperty import ProductSortProperty
from .productupdate import (
    ProductUpdate,
    ProductUpdateMetadata,
    ProductUpdateMetadataTypedDict,
    ProductUpdatePrices,
    ProductUpdatePricesTypedDict,
    ProductUpdateTypedDict,
)
from .propertyaggregation import Func, PropertyAggregation, PropertyAggregationTypedDict
from .reactions import Reactions, ReactionsTypedDict
from .refreshtokenrequest import RefreshTokenRequest, RefreshTokenRequestTypedDict
from .refund import Refund, RefundMetadata, RefundMetadataTypedDict, RefundTypedDict
from .refundamounttoohigh import RefundAmountTooHigh, RefundAmountTooHighData
from .refundcreate import (
    RefundCreate,
    RefundCreateMetadata,
    RefundCreateMetadataTypedDict,
    RefundCreateTypedDict,
)
from .refundedalready import RefundedAlready, RefundedAlreadyData
from .refundreason import RefundReason
from .refunds_listop import (
    OrderIDFilter,
    OrderIDFilterTypedDict,
    RefundIDFilter,
    RefundIDFilterTypedDict,
    RefundsListQueryParamCustomerIDFilter,
    RefundsListQueryParamCustomerIDFilterTypedDict,
    RefundsListQueryParamOrganizationIDFilter,
    RefundsListQueryParamOrganizationIDFilterTypedDict,
    RefundsListRequest,
    RefundsListRequestTypedDict,
    RefundsListResponse,
    RefundsListResponseTypedDict,
    SubscriptionIDFilter,
    SubscriptionIDFilterTypedDict,
)
from .refundsortproperty import RefundSortProperty
from .refundstatus import RefundStatus
from .repositories_getop import RepositoriesGetRequest, RepositoriesGetRequestTypedDict
from .repositories_listop import (
    ExternalOrganizationNameFilter,
    ExternalOrganizationNameFilterTypedDict,
    QueryParamOrganizationIDFilter,
    QueryParamOrganizationIDFilterTypedDict,
    QueryParamPlatformFilter,
    QueryParamPlatformFilterTypedDict,
    QueryParamRepositoryNameFilter,
    QueryParamRepositoryNameFilterTypedDict,
    RepositoriesListRequest,
    RepositoriesListRequestTypedDict,
    RepositoriesListResponse,
    RepositoriesListResponseTypedDict,
)
from .repositories_updateop import (
    RepositoriesUpdateRequest,
    RepositoriesUpdateRequestTypedDict,
)
from .repository import Repository, RepositoryTypedDict
from .repositoryprofilesettings import (
    RepositoryProfileSettings,
    RepositoryProfileSettingsTypedDict,
)
from .repositoryprofilesettingsupdate import (
    RepositoryProfileSettingsUpdate,
    RepositoryProfileSettingsUpdateTypedDict,
)
from .repositorysortproperty import RepositorySortProperty
from .repositoryupdate import RepositoryUpdate, RepositoryUpdateTypedDict
from .resourcenotfound import ResourceNotFound, ResourceNotFoundData
from .revoketokenrequest import (
    RevokeTokenRequest,
    RevokeTokenRequestTypedDict,
    TokenTypeHint,
)
from .revoketokenresponse import RevokeTokenResponse, RevokeTokenResponseTypedDict
from .s3downloadurl import S3DownloadURL, S3DownloadURLTypedDict
from .s3filecreatemultipart import S3FileCreateMultipart, S3FileCreateMultipartTypedDict
from .s3filecreatepart import S3FileCreatePart, S3FileCreatePartTypedDict
from .s3fileuploadcompletedpart import (
    S3FileUploadCompletedPart,
    S3FileUploadCompletedPartTypedDict,
)
from .s3fileuploadmultipart import S3FileUploadMultipart, S3FileUploadMultipartTypedDict
from .s3fileuploadpart import S3FileUploadPart, S3FileUploadPartTypedDict
from .scope import Scope
from .sdkerror import SDKError
from .security import Security, SecurityTypedDict
from .state import State
from .subscription import (
    CustomFieldData,
    CustomFieldDataTypedDict,
    Metadata,
    MetadataTypedDict,
    Price,
    PriceTypedDict,
    Subscription,
    SubscriptionDiscount,
    SubscriptionDiscountTypedDict,
    SubscriptionPrices,
    SubscriptionPricesTypedDict,
    SubscriptionTypedDict,
)
from .subscriptioncancel import SubscriptionCancel, SubscriptionCancelTypedDict
from .subscriptioncustomer import (
    SubscriptionCustomer,
    SubscriptionCustomerMetadata,
    SubscriptionCustomerMetadataTypedDict,
    SubscriptionCustomerTypedDict,
    TaxID,
    TaxIDTypedDict,
)
from .subscriptionprorationbehavior import SubscriptionProrationBehavior
from .subscriptionrecurringinterval import SubscriptionRecurringInterval
from .subscriptions_exportop import (
    OrganizationID,
    OrganizationIDTypedDict,
    SubscriptionsExportRequest,
    SubscriptionsExportRequestTypedDict,
)
from .subscriptions_getop import (
    SubscriptionsGetRequest,
    SubscriptionsGetRequestTypedDict,
)
from .subscriptions_listop import (
    CustomerIDFilter,
    CustomerIDFilterTypedDict,
    DiscountIDFilter,
    DiscountIDFilterTypedDict,
    ProductIDFilter,
    ProductIDFilterTypedDict,
    SubscriptionsListQueryParamOrganizationIDFilter,
    SubscriptionsListQueryParamOrganizationIDFilterTypedDict,
    SubscriptionsListRequest,
    SubscriptionsListRequestTypedDict,
    SubscriptionsListResponse,
    SubscriptionsListResponseTypedDict,
)
from .subscriptions_revokeop import (
    SubscriptionsRevokeRequest,
    SubscriptionsRevokeRequestTypedDict,
)
from .subscriptions_updateop import (
    SubscriptionsUpdateRequest,
    SubscriptionsUpdateRequestTypedDict,
)
from .subscriptionsortproperty import SubscriptionSortProperty
from .subscriptionstatus import SubscriptionStatus
from .subscriptionupdate import SubscriptionUpdate, SubscriptionUpdateTypedDict
from .subscriptionupdateproduct import (
    SubscriptionUpdateProduct,
    SubscriptionUpdateProductTypedDict,
)
from .subscriptionuser import SubscriptionUser, SubscriptionUserTypedDict
from .subtype import SubType
from .taxidformat import TaxIDFormat
from .timeinterval import TimeInterval
from .tokenresponse import TokenResponse, TokenResponseTypedDict
from .unauthorized import Unauthorized, UnauthorizedData
from .userinfoorganization import UserInfoOrganization, UserInfoOrganizationTypedDict
from .userinfouser import UserInfoUser, UserInfoUserTypedDict
from .validatedlicensekey import ValidatedLicenseKey, ValidatedLicenseKeyTypedDict
from .validationerror import (
    Loc,
    LocTypedDict,
    ValidationError,
    ValidationErrorTypedDict,
)
from .webhookbenefitcreatedpayload import (
    WebhookBenefitCreatedPayload,
    WebhookBenefitCreatedPayloadTypedDict,
)
from .webhookbenefitgrantcreatedpayload import (
    WebhookBenefitGrantCreatedPayload,
    WebhookBenefitGrantCreatedPayloadTypedDict,
)
from .webhookbenefitgrantrevokedpayload import (
    WebhookBenefitGrantRevokedPayload,
    WebhookBenefitGrantRevokedPayloadTypedDict,
)
from .webhookbenefitgrantupdatedpayload import (
    WebhookBenefitGrantUpdatedPayload,
    WebhookBenefitGrantUpdatedPayloadTypedDict,
)
from .webhookbenefitupdatedpayload import (
    WebhookBenefitUpdatedPayload,
    WebhookBenefitUpdatedPayloadTypedDict,
)
from .webhookcheckoutcreatedpayload import (
    WebhookCheckoutCreatedPayload,
    WebhookCheckoutCreatedPayloadTypedDict,
)
from .webhookcheckoutupdatedpayload import (
    WebhookCheckoutUpdatedPayload,
    WebhookCheckoutUpdatedPayloadTypedDict,
)
from .webhookcustomercreatedpayload import (
    WebhookCustomerCreatedPayload,
    WebhookCustomerCreatedPayloadTypedDict,
)
from .webhookcustomerdeletedpayload import (
    WebhookCustomerDeletedPayload,
    WebhookCustomerDeletedPayloadTypedDict,
)
from .webhookcustomerstatechangedpayload import (
    WebhookCustomerStateChangedPayload,
    WebhookCustomerStateChangedPayloadTypedDict,
)
from .webhookcustomerupdatedpayload import (
    WebhookCustomerUpdatedPayload,
    WebhookCustomerUpdatedPayloadTypedDict,
)
from .webhookordercreatedpayload import (
    WebhookOrderCreatedPayload,
    WebhookOrderCreatedPayloadTypedDict,
)
from .webhookorderpaidpayload import (
    WebhookOrderPaidPayload,
    WebhookOrderPaidPayloadTypedDict,
)
from .webhookorderrefundedpayload import (
    WebhookOrderRefundedPayload,
    WebhookOrderRefundedPayloadTypedDict,
)
from .webhookorderupdatedpayload import (
    WebhookOrderUpdatedPayload,
    WebhookOrderUpdatedPayloadTypedDict,
)
from .webhookorganizationupdatedpayload import (
    WebhookOrganizationUpdatedPayload,
    WebhookOrganizationUpdatedPayloadTypedDict,
)
from .webhookpledgecreatedpayload import (
    WebhookPledgeCreatedPayload,
    WebhookPledgeCreatedPayloadTypedDict,
)
from .webhookpledgeupdatedpayload import (
    WebhookPledgeUpdatedPayload,
    WebhookPledgeUpdatedPayloadTypedDict,
)
from .webhookproductcreatedpayload import (
    WebhookProductCreatedPayload,
    WebhookProductCreatedPayloadTypedDict,
)
from .webhookproductupdatedpayload import (
    WebhookProductUpdatedPayload,
    WebhookProductUpdatedPayloadTypedDict,
)
from .webhookrefundcreatedpayload import (
    WebhookRefundCreatedPayload,
    WebhookRefundCreatedPayloadTypedDict,
)
from .webhookrefundupdatedpayload import (
    WebhookRefundUpdatedPayload,
    WebhookRefundUpdatedPayloadTypedDict,
)
from .webhooksubscriptionactivepayload import (
    WebhookSubscriptionActivePayload,
    WebhookSubscriptionActivePayloadTypedDict,
)
from .webhooksubscriptioncanceledpayload import (
    WebhookSubscriptionCanceledPayload,
    WebhookSubscriptionCanceledPayloadTypedDict,
)
from .webhooksubscriptioncreatedpayload import (
    WebhookSubscriptionCreatedPayload,
    WebhookSubscriptionCreatedPayloadTypedDict,
)
from .webhooksubscriptionrevokedpayload import (
    WebhookSubscriptionRevokedPayload,
    WebhookSubscriptionRevokedPayloadTypedDict,
)
from .webhooksubscriptionuncanceledpayload import (
    WebhookSubscriptionUncanceledPayload,
    WebhookSubscriptionUncanceledPayloadTypedDict,
)
from .webhooksubscriptionupdatedpayload import (
    WebhookSubscriptionUpdatedPayload,
    WebhookSubscriptionUpdatedPayloadTypedDict,
)


__all__ = [
    "Address",
    "AddressTypedDict",
    "Aggregation",
    "AggregationTypedDict",
    "AlreadyActiveSubscriptionError",
    "AlreadyActiveSubscriptionErrorData",
    "AlreadyCanceledSubscription",
    "AlreadyCanceledSubscriptionData",
    "Assignee",
    "AssigneeTypedDict",
    "AttachedCustomField",
    "AttachedCustomFieldCreate",
    "AttachedCustomFieldCreateTypedDict",
    "AttachedCustomFieldTypedDict",
    "Author",
    "AuthorTypedDict",
    "AuthorizationCodeTokenRequest",
    "AuthorizationCodeTokenRequestTypedDict",
    "AuthorizeOrganization",
    "AuthorizeOrganizationTypedDict",
    "AuthorizeResponseOrganization",
    "AuthorizeResponseOrganizationTypedDict",
    "AuthorizeResponseUser",
    "AuthorizeResponseUserTypedDict",
    "AuthorizeUser",
    "AuthorizeUserTypedDict",
    "Benefit",
    "BenefitBase",
    "BenefitBaseTypedDict",
    "BenefitCreate",
    "BenefitCreateTypedDict",
    "BenefitCustom",
    "BenefitCustomCreate",
    "BenefitCustomCreateProperties",
    "BenefitCustomCreatePropertiesTypedDict",
    "BenefitCustomCreateTypedDict",
    "BenefitCustomProperties",
    "BenefitCustomPropertiesTypedDict",
    "BenefitCustomSubscriber",
    "BenefitCustomSubscriberProperties",
    "BenefitCustomSubscriberPropertiesTypedDict",
    "BenefitCustomSubscriberTypedDict",
    "BenefitCustomTypedDict",
    "BenefitCustomUpdate",
    "BenefitCustomUpdateTypedDict",
    "BenefitDiscord",
    "BenefitDiscordCreate",
    "BenefitDiscordCreateProperties",
    "BenefitDiscordCreatePropertiesTypedDict",
    "BenefitDiscordCreateTypedDict",
    "BenefitDiscordProperties",
    "BenefitDiscordPropertiesTypedDict",
    "BenefitDiscordSubscriber",
    "BenefitDiscordSubscriberProperties",
    "BenefitDiscordSubscriberPropertiesTypedDict",
    "BenefitDiscordSubscriberTypedDict",
    "BenefitDiscordTypedDict",
    "BenefitDiscordUpdate",
    "BenefitDiscordUpdateTypedDict",
    "BenefitDownloadables",
    "BenefitDownloadablesCreate",
    "BenefitDownloadablesCreateProperties",
    "BenefitDownloadablesCreatePropertiesTypedDict",
    "BenefitDownloadablesCreateTypedDict",
    "BenefitDownloadablesProperties",
    "BenefitDownloadablesPropertiesTypedDict",
    "BenefitDownloadablesSubscriber",
    "BenefitDownloadablesSubscriberProperties",
    "BenefitDownloadablesSubscriberPropertiesTypedDict",
    "BenefitDownloadablesSubscriberTypedDict",
    "BenefitDownloadablesTypedDict",
    "BenefitDownloadablesUpdate",
    "BenefitDownloadablesUpdateTypedDict",
    "BenefitGitHubRepository",
    "BenefitGitHubRepositoryCreate",
    "BenefitGitHubRepositoryCreateProperties",
    "BenefitGitHubRepositoryCreatePropertiesPermission",
    "BenefitGitHubRepositoryCreatePropertiesTypedDict",
    "BenefitGitHubRepositoryCreateTypedDict",
    "BenefitGitHubRepositoryProperties",
    "BenefitGitHubRepositoryPropertiesTypedDict",
    "BenefitGitHubRepositorySubscriber",
    "BenefitGitHubRepositorySubscriberProperties",
    "BenefitGitHubRepositorySubscriberPropertiesTypedDict",
    "BenefitGitHubRepositorySubscriberTypedDict",
    "BenefitGitHubRepositoryTypedDict",
    "BenefitGitHubRepositoryUpdate",
    "BenefitGitHubRepositoryUpdateTypedDict",
    "BenefitGrant",
    "BenefitGrantCustomProperties",
    "BenefitGrantCustomPropertiesTypedDict",
    "BenefitGrantDiscordProperties",
    "BenefitGrantDiscordPropertiesTypedDict",
    "BenefitGrantDownloadablesProperties",
    "BenefitGrantDownloadablesPropertiesTypedDict",
    "BenefitGrantGitHubRepositoryProperties",
    "BenefitGrantGitHubRepositoryPropertiesPermission",
    "BenefitGrantGitHubRepositoryPropertiesTypedDict",
    "BenefitGrantLicenseKeysProperties",
    "BenefitGrantLicenseKeysPropertiesTypedDict",
    "BenefitGrantTypedDict",
    "BenefitGrantWebhook",
    "BenefitGrantWebhookProperties",
    "BenefitGrantWebhookPropertiesTypedDict",
    "BenefitGrantWebhookTypedDict",
    "BenefitIDFilter",
    "BenefitIDFilterTypedDict",
    "BenefitLicenseKeyActivationProperties",
    "BenefitLicenseKeyActivationPropertiesTypedDict",
    "BenefitLicenseKeyExpirationProperties",
    "BenefitLicenseKeyExpirationPropertiesTypedDict",
    "BenefitLicenseKeys",
    "BenefitLicenseKeysCreate",
    "BenefitLicenseKeysCreateProperties",
    "BenefitLicenseKeysCreatePropertiesTypedDict",
    "BenefitLicenseKeysCreateTypedDict",
    "BenefitLicenseKeysProperties",
    "BenefitLicenseKeysPropertiesTypedDict",
    "BenefitLicenseKeysSubscriber",
    "BenefitLicenseKeysSubscriberProperties",
    "BenefitLicenseKeysSubscriberPropertiesTypedDict",
    "BenefitLicenseKeysSubscriberTypedDict",
    "BenefitLicenseKeysTypedDict",
    "BenefitLicenseKeysUpdate",
    "BenefitLicenseKeysUpdateTypedDict",
    "BenefitType",
    "BenefitTypeFilter",
    "BenefitTypeFilterTypedDict",
    "BenefitTypedDict",
    "BenefitsDeleteRequest",
    "BenefitsDeleteRequestTypedDict",
    "BenefitsGetRequest",
    "BenefitsGetRequestTypedDict",
    "BenefitsGrantsRequest",
    "BenefitsGrantsRequestTypedDict",
    "BenefitsGrantsResponse",
    "BenefitsGrantsResponseTypedDict",
    "BenefitsListQueryParamOrganizationIDFilter",
    "BenefitsListQueryParamOrganizationIDFilterTypedDict",
    "BenefitsListRequest",
    "BenefitsListRequestTypedDict",
    "BenefitsListResponse",
    "BenefitsListResponseTypedDict",
    "BenefitsUpdateBenefitUpdate",
    "BenefitsUpdateBenefitUpdateTypedDict",
    "BenefitsUpdateRequest",
    "BenefitsUpdateRequestTypedDict",
    "Checkout",
    "CheckoutConfirmStripe",
    "CheckoutConfirmStripeCustomFieldData",
    "CheckoutConfirmStripeCustomFieldDataTypedDict",
    "CheckoutConfirmStripeTypedDict",
    "CheckoutCreate",
    "CheckoutCreateTypedDict",
    "CheckoutCustomFieldData",
    "CheckoutCustomFieldDataTypedDict",
    "CheckoutDiscount",
    "CheckoutDiscountFixedOnceForeverDuration",
    "CheckoutDiscountFixedOnceForeverDurationTypedDict",
    "CheckoutDiscountFixedRepeatDuration",
    "CheckoutDiscountFixedRepeatDurationTypedDict",
    "CheckoutDiscountPercentageOnceForeverDuration",
    "CheckoutDiscountPercentageOnceForeverDurationTypedDict",
    "CheckoutDiscountPercentageRepeatDuration",
    "CheckoutDiscountPercentageRepeatDurationTypedDict",
    "CheckoutDiscountTypedDict",
    "CheckoutForbiddenError",
    "CheckoutForbiddenErrorUnion",
    "CheckoutIDFilter",
    "CheckoutIDFilterTypedDict",
    "CheckoutLink",
    "CheckoutLinkCreateProduct",
    "CheckoutLinkCreateProductMetadata",
    "CheckoutLinkCreateProductMetadataTypedDict",
    "CheckoutLinkCreateProductPrice",
    "CheckoutLinkCreateProductPriceMetadata",
    "CheckoutLinkCreateProductPriceMetadataTypedDict",
    "CheckoutLinkCreateProductPriceTypedDict",
    "CheckoutLinkCreateProductTypedDict",
    "CheckoutLinkCreateProducts",
    "CheckoutLinkCreateProductsMetadata",
    "CheckoutLinkCreateProductsMetadataTypedDict",
    "CheckoutLinkCreateProductsTypedDict",
    "CheckoutLinkDiscount",
    "CheckoutLinkDiscountTypedDict",
    "CheckoutLinkMetadata",
    "CheckoutLinkMetadataTypedDict",
    "CheckoutLinkProduct",
    "CheckoutLinkProductPrice",
    "CheckoutLinkProductPriceTypedDict",
    "CheckoutLinkProductPrices",
    "CheckoutLinkProductPricesTypedDict",
    "CheckoutLinkProductTypedDict",
    "CheckoutLinkSortProperty",
    "CheckoutLinkTypedDict",
    "CheckoutLinkUpdate",
    "CheckoutLinkUpdateMetadata",
    "CheckoutLinkUpdateMetadataTypedDict",
    "CheckoutLinkUpdateTypedDict",
    "CheckoutLinksCreateCheckoutLinkCreate",
    "CheckoutLinksCreateCheckoutLinkCreateTypedDict",
    "CheckoutLinksDeleteRequest",
    "CheckoutLinksDeleteRequestTypedDict",
    "CheckoutLinksGetRequest",
    "CheckoutLinksGetRequestTypedDict",
    "CheckoutLinksListQueryParamOrganizationIDFilter",
    "CheckoutLinksListQueryParamOrganizationIDFilterTypedDict",
    "CheckoutLinksListQueryParamProductIDFilter",
    "CheckoutLinksListQueryParamProductIDFilterTypedDict",
    "CheckoutLinksListRequest",
    "CheckoutLinksListRequestTypedDict",
    "CheckoutLinksListResponse",
    "CheckoutLinksListResponseTypedDict",
    "CheckoutLinksUpdateRequest",
    "CheckoutLinksUpdateRequestTypedDict",
    "CheckoutMetadata",
    "CheckoutMetadataTypedDict",
    "CheckoutPriceCreate",
    "CheckoutPriceCreateCustomFieldData",
    "CheckoutPriceCreateCustomFieldDataTypedDict",
    "CheckoutPriceCreateCustomerMetadata",
    "CheckoutPriceCreateCustomerMetadataTypedDict",
    "CheckoutPriceCreateMetadata",
    "CheckoutPriceCreateMetadataTypedDict",
    "CheckoutPriceCreateTypedDict",
    "CheckoutProduct",
    "CheckoutProductCreate",
    "CheckoutProductCreateCustomFieldData",
    "CheckoutProductCreateCustomFieldDataTypedDict",
    "CheckoutProductCreateCustomerMetadata",
    "CheckoutProductCreateCustomerMetadataTypedDict",
    "CheckoutProductCreateMetadata",
    "CheckoutProductCreateMetadataTypedDict",
    "CheckoutProductCreateTypedDict",
    "CheckoutProductPrice",
    "CheckoutProductPriceTypedDict",
    "CheckoutProductPrices",
    "CheckoutProductPricesTypedDict",
    "CheckoutProductTypedDict",
    "CheckoutProductsCreate",
    "CheckoutProductsCreateCustomFieldData",
    "CheckoutProductsCreateCustomFieldDataTypedDict",
    "CheckoutProductsCreateCustomerMetadata",
    "CheckoutProductsCreateCustomerMetadataTypedDict",
    "CheckoutProductsCreateMetadata",
    "CheckoutProductsCreateMetadataTypedDict",
    "CheckoutProductsCreateTypedDict",
    "CheckoutPublic",
    "CheckoutPublicConfirmed",
    "CheckoutPublicConfirmedCustomFieldData",
    "CheckoutPublicConfirmedCustomFieldDataTypedDict",
    "CheckoutPublicConfirmedDiscount",
    "CheckoutPublicConfirmedDiscountTypedDict",
    "CheckoutPublicConfirmedProductPrice",
    "CheckoutPublicConfirmedProductPriceTypedDict",
    "CheckoutPublicConfirmedTypedDict",
    "CheckoutPublicCustomFieldData",
    "CheckoutPublicCustomFieldDataTypedDict",
    "CheckoutPublicDiscount",
    "CheckoutPublicDiscountTypedDict",
    "CheckoutPublicProductPrice",
    "CheckoutPublicProductPriceTypedDict",
    "CheckoutPublicTypedDict",
    "CheckoutSortProperty",
    "CheckoutStatus",
    "CheckoutTypedDict",
    "CheckoutUpdate",
    "CheckoutUpdateCustomFieldData",
    "CheckoutUpdateCustomFieldDataTypedDict",
    "CheckoutUpdateCustomerMetadata",
    "CheckoutUpdateCustomerMetadataTypedDict",
    "CheckoutUpdateMetadata",
    "CheckoutUpdateMetadataTypedDict",
    "CheckoutUpdatePublic",
    "CheckoutUpdatePublicCustomFieldData",
    "CheckoutUpdatePublicCustomFieldDataTypedDict",
    "CheckoutUpdatePublicTypedDict",
    "CheckoutUpdateTypedDict",
    "CheckoutsClientConfirmRequest",
    "CheckoutsClientConfirmRequestTypedDict",
    "CheckoutsClientGetRequest",
    "CheckoutsClientGetRequestTypedDict",
    "CheckoutsClientUpdateRequest",
    "CheckoutsClientUpdateRequestTypedDict",
    "CheckoutsGetRequest",
    "CheckoutsGetRequestTypedDict",
    "CheckoutsListQueryParamOrganizationIDFilter",
    "CheckoutsListQueryParamOrganizationIDFilterTypedDict",
    "CheckoutsListQueryParamProductIDFilter",
    "CheckoutsListQueryParamProductIDFilterTypedDict",
    "CheckoutsListRequest",
    "CheckoutsListRequestTypedDict",
    "CheckoutsListResponse",
    "CheckoutsListResponseTypedDict",
    "CheckoutsUpdateRequest",
    "CheckoutsUpdateRequestTypedDict",
    "Clauses",
    "ClausesTypedDict",
    "Conditions",
    "ConditionsTypedDict",
    "CountAggregation",
    "CountAggregationTypedDict",
    "CurrencyAmount",
    "CurrencyAmountTypedDict",
    "CustomField",
    "CustomFieldCheckbox",
    "CustomFieldCheckboxMetadata",
    "CustomFieldCheckboxMetadataTypedDict",
    "CustomFieldCheckboxProperties",
    "CustomFieldCheckboxPropertiesTypedDict",
    "CustomFieldCheckboxTypedDict",
    "CustomFieldCreate",
    "CustomFieldCreateCheckbox",
    "CustomFieldCreateCheckboxMetadata",
    "CustomFieldCreateCheckboxMetadataTypedDict",
    "CustomFieldCreateCheckboxTypedDict",
    "CustomFieldCreateDate",
    "CustomFieldCreateDateMetadata",
    "CustomFieldCreateDateMetadataTypedDict",
    "CustomFieldCreateDateTypedDict",
    "CustomFieldCreateNumber",
    "CustomFieldCreateNumberMetadata",
    "CustomFieldCreateNumberMetadataTypedDict",
    "CustomFieldCreateNumberTypedDict",
    "CustomFieldCreateSelect",
    "CustomFieldCreateSelectMetadata",
    "CustomFieldCreateSelectMetadataTypedDict",
    "CustomFieldCreateSelectTypedDict",
    "CustomFieldCreateText",
    "CustomFieldCreateTextMetadata",
    "CustomFieldCreateTextMetadataTypedDict",
    "CustomFieldCreateTextTypedDict",
    "CustomFieldCreateTypedDict",
    "CustomFieldData",
    "CustomFieldDataTypedDict",
    "CustomFieldDate",
    "CustomFieldDateMetadata",
    "CustomFieldDateMetadataTypedDict",
    "CustomFieldDateProperties",
    "CustomFieldDatePropertiesTypedDict",
    "CustomFieldDateTypedDict",
    "CustomFieldNumber",
    "CustomFieldNumberMetadata",
    "CustomFieldNumberMetadataTypedDict",
    "CustomFieldNumberProperties",
    "CustomFieldNumberPropertiesTypedDict",
    "CustomFieldNumberTypedDict",
    "CustomFieldSelect",
    "CustomFieldSelectMetadata",
    "CustomFieldSelectMetadataTypedDict",
    "CustomFieldSelectOption",
    "CustomFieldSelectOptionTypedDict",
    "CustomFieldSelectProperties",
    "CustomFieldSelectPropertiesTypedDict",
    "CustomFieldSelectTypedDict",
    "CustomFieldSortProperty",
    "CustomFieldText",
    "CustomFieldTextMetadata",
    "CustomFieldTextMetadataTypedDict",
    "CustomFieldTextProperties",
    "CustomFieldTextPropertiesTypedDict",
    "CustomFieldTextTypedDict",
    "CustomFieldType",
    "CustomFieldTypeFilter",
    "CustomFieldTypeFilterTypedDict",
    "CustomFieldTypedDict",
    "CustomFieldUpdate",
    "CustomFieldUpdateCheckbox",
    "CustomFieldUpdateCheckboxMetadata",
    "CustomFieldUpdateCheckboxMetadataTypedDict",
    "CustomFieldUpdateCheckboxTypedDict",
    "CustomFieldUpdateDate",
    "CustomFieldUpdateDateMetadata",
    "CustomFieldUpdateDateMetadataTypedDict",
    "CustomFieldUpdateDateTypedDict",
    "CustomFieldUpdateNumber",
    "CustomFieldUpdateNumberMetadata",
    "CustomFieldUpdateNumberMetadataTypedDict",
    "CustomFieldUpdateNumberTypedDict",
    "CustomFieldUpdateSelect",
    "CustomFieldUpdateSelectMetadata",
    "CustomFieldUpdateSelectMetadataTypedDict",
    "CustomFieldUpdateSelectTypedDict",
    "CustomFieldUpdateText",
    "CustomFieldUpdateTextMetadata",
    "CustomFieldUpdateTextMetadataTypedDict",
    "CustomFieldUpdateTextTypedDict",
    "CustomFieldUpdateTypedDict",
    "CustomFieldsDeleteRequest",
    "CustomFieldsDeleteRequestTypedDict",
    "CustomFieldsGetRequest",
    "CustomFieldsGetRequestTypedDict",
    "CustomFieldsListQueryParamOrganizationIDFilter",
    "CustomFieldsListQueryParamOrganizationIDFilterTypedDict",
    "CustomFieldsListRequest",
    "CustomFieldsListRequestTypedDict",
    "CustomFieldsListResponse",
    "CustomFieldsListResponseTypedDict",
    "CustomFieldsUpdateRequest",
    "CustomFieldsUpdateRequestTypedDict",
    "Customer",
    "CustomerBenefitGrant",
    "CustomerBenefitGrantCustom",
    "CustomerBenefitGrantCustomTypedDict",
    "CustomerBenefitGrantCustomUpdate",
    "CustomerBenefitGrantCustomUpdateTypedDict",
    "CustomerBenefitGrantDiscord",
    "CustomerBenefitGrantDiscordPropertiesUpdate",
    "CustomerBenefitGrantDiscordPropertiesUpdateTypedDict",
    "CustomerBenefitGrantDiscordTypedDict",
    "CustomerBenefitGrantDiscordUpdate",
    "CustomerBenefitGrantDiscordUpdateTypedDict",
    "CustomerBenefitGrantDownloadables",
    "CustomerBenefitGrantDownloadablesTypedDict",
    "CustomerBenefitGrantDownloadablesUpdate",
    "CustomerBenefitGrantDownloadablesUpdateTypedDict",
    "CustomerBenefitGrantGitHubRepository",
    "CustomerBenefitGrantGitHubRepositoryPropertiesUpdate",
    "CustomerBenefitGrantGitHubRepositoryPropertiesUpdateTypedDict",
    "CustomerBenefitGrantGitHubRepositoryTypedDict",
    "CustomerBenefitGrantGitHubRepositoryUpdate",
    "CustomerBenefitGrantGitHubRepositoryUpdateTypedDict",
    "CustomerBenefitGrantLicenseKeys",
    "CustomerBenefitGrantLicenseKeysTypedDict",
    "CustomerBenefitGrantLicenseKeysUpdate",
    "CustomerBenefitGrantLicenseKeysUpdateTypedDict",
    "CustomerBenefitGrantSortProperty",
    "CustomerBenefitGrantTypedDict",
    "CustomerBenefitGrantUpdate",
    "CustomerBenefitGrantUpdateTypedDict",
    "CustomerCancellationReason",
    "CustomerCreate",
    "CustomerCreateMetadata",
    "CustomerCreateMetadataTypedDict",
    "CustomerCreateTaxID",
    "CustomerCreateTaxIDTypedDict",
    "CustomerCreateTypedDict",
    "CustomerIDFilter",
    "CustomerIDFilterTypedDict",
    "CustomerMetadata",
    "CustomerMetadata1",
    "CustomerMetadata1TypedDict",
    "CustomerMetadataTypedDict",
    "CustomerOrder",
    "CustomerOrderInvoice",
    "CustomerOrderInvoiceTypedDict",
    "CustomerOrderProduct",
    "CustomerOrderProductPrice",
    "CustomerOrderProductPriceTypedDict",
    "CustomerOrderProductPrices",
    "CustomerOrderProductPricesTypedDict",
    "CustomerOrderProductTypedDict",
    "CustomerOrderSortProperty",
    "CustomerOrderSubscription",
    "CustomerOrderSubscriptionTypedDict",
    "CustomerOrderTypedDict",
    "CustomerOrganization",
    "CustomerOrganizationTypedDict",
    "CustomerPaymentMethodCreate",
    "CustomerPaymentMethodCreateTypedDict",
    "CustomerPortalBenefitGrantsGetRequest",
    "CustomerPortalBenefitGrantsGetRequestTypedDict",
    "CustomerPortalBenefitGrantsGetSecurity",
    "CustomerPortalBenefitGrantsGetSecurityTypedDict",
    "CustomerPortalBenefitGrantsListQueryParamBenefitIDFilter",
    "CustomerPortalBenefitGrantsListQueryParamBenefitIDFilterTypedDict",
    "CustomerPortalBenefitGrantsListQueryParamOrganizationIDFilter",
    "CustomerPortalBenefitGrantsListQueryParamOrganizationIDFilterTypedDict",
    "CustomerPortalBenefitGrantsListRequest",
    "CustomerPortalBenefitGrantsListRequestTypedDict",
    "CustomerPortalBenefitGrantsListResponse",
    "CustomerPortalBenefitGrantsListResponseTypedDict",
    "CustomerPortalBenefitGrantsListSecurity",
    "CustomerPortalBenefitGrantsListSecurityTypedDict",
    "CustomerPortalBenefitGrantsUpdateRequest",
    "CustomerPortalBenefitGrantsUpdateRequestTypedDict",
    "CustomerPortalBenefitGrantsUpdateSecurity",
    "CustomerPortalBenefitGrantsUpdateSecurityTypedDict",
    "CustomerPortalCustomer",
    "CustomerPortalCustomerTaxID",
    "CustomerPortalCustomerTaxIDTypedDict",
    "CustomerPortalCustomerTypedDict",
    "CustomerPortalCustomerUpdate",
    "CustomerPortalCustomerUpdateTypedDict",
    "CustomerPortalCustomersAddPaymentMethodResponseCustomerPortalCustomersAddPaymentMethod",
    "CustomerPortalCustomersAddPaymentMethodResponseCustomerPortalCustomersAddPaymentMethodTypedDict",
    "CustomerPortalCustomersAddPaymentMethodSecurity",
    "CustomerPortalCustomersAddPaymentMethodSecurityTypedDict",
    "CustomerPortalCustomersDeletePaymentMethodRequest",
    "CustomerPortalCustomersDeletePaymentMethodRequestTypedDict",
    "CustomerPortalCustomersDeletePaymentMethodSecurity",
    "CustomerPortalCustomersDeletePaymentMethodSecurityTypedDict",
    "CustomerPortalCustomersGetPaymentMethodsRequest",
    "CustomerPortalCustomersGetPaymentMethodsRequestTypedDict",
    "CustomerPortalCustomersGetPaymentMethodsResponse",
    "CustomerPortalCustomersGetPaymentMethodsResponseTypedDict",
    "CustomerPortalCustomersGetPaymentMethodsSecurity",
    "CustomerPortalCustomersGetPaymentMethodsSecurityTypedDict",
    "CustomerPortalCustomersGetSecurity",
    "CustomerPortalCustomersGetSecurityTypedDict",
    "CustomerPortalCustomersUpdateSecurity",
    "CustomerPortalCustomersUpdateSecurityTypedDict",
    "CustomerPortalDownloadablesCustomerPortalDownloadablesGetRequest",
    "CustomerPortalDownloadablesCustomerPortalDownloadablesGetRequestTypedDict",
    "CustomerPortalDownloadablesListQueryParamBenefitIDFilter",
    "CustomerPortalDownloadablesListQueryParamBenefitIDFilterTypedDict",
    "CustomerPortalDownloadablesListQueryParamOrganizationIDFilter",
    "CustomerPortalDownloadablesListQueryParamOrganizationIDFilterTypedDict",
    "CustomerPortalDownloadablesListRequest",
    "CustomerPortalDownloadablesListRequestTypedDict",
    "CustomerPortalDownloadablesListResponse",
    "CustomerPortalDownloadablesListResponseTypedDict",
    "CustomerPortalDownloadablesListSecurity",
    "CustomerPortalDownloadablesListSecurityTypedDict",
    "CustomerPortalLicenseKeysGetRequest",
    "CustomerPortalLicenseKeysGetRequestTypedDict",
    "CustomerPortalLicenseKeysGetSecurity",
    "CustomerPortalLicenseKeysGetSecurityTypedDict",
    "CustomerPortalLicenseKeysListQueryParamOrganizationIDFilter",
    "CustomerPortalLicenseKeysListQueryParamOrganizationIDFilterTypedDict",
    "CustomerPortalLicenseKeysListRequest",
    "CustomerPortalLicenseKeysListRequestTypedDict",
    "CustomerPortalLicenseKeysListResponse",
    "CustomerPortalLicenseKeysListResponseTypedDict",
    "CustomerPortalLicenseKeysListSecurity",
    "CustomerPortalLicenseKeysListSecurityTypedDict",
    "CustomerPortalOAuthAccount",
    "CustomerPortalOAuthAccountTypedDict",
    "CustomerPortalOrdersGetRequest",
    "CustomerPortalOrdersGetRequestTypedDict",
    "CustomerPortalOrdersGetSecurity",
    "CustomerPortalOrdersGetSecurityTypedDict",
    "CustomerPortalOrdersInvoiceRequest",
    "CustomerPortalOrdersInvoiceRequestTypedDict",
    "CustomerPortalOrdersInvoiceSecurity",
    "CustomerPortalOrdersInvoiceSecurityTypedDict",
    "CustomerPortalOrdersListQueryParamOrganizationIDFilter",
    "CustomerPortalOrdersListQueryParamOrganizationIDFilterTypedDict",
    "CustomerPortalOrdersListQueryParamProductBillingTypeFilter",
    "CustomerPortalOrdersListQueryParamProductBillingTypeFilterTypedDict",
    "CustomerPortalOrdersListQueryParamProductIDFilter",
    "CustomerPortalOrdersListQueryParamProductIDFilterTypedDict",
    "CustomerPortalOrdersListQueryParamSubscriptionIDFilter",
    "CustomerPortalOrdersListQueryParamSubscriptionIDFilterTypedDict",
    "CustomerPortalOrdersListRequest",
    "CustomerPortalOrdersListRequestTypedDict",
    "CustomerPortalOrdersListResponse",
    "CustomerPortalOrdersListResponseTypedDict",
    "CustomerPortalOrdersListSecurity",
    "CustomerPortalOrdersListSecurityTypedDict",
    "CustomerPortalOrganizationsGetRequest",
    "CustomerPortalOrganizationsGetRequestTypedDict",
    "CustomerPortalSubscriptionsCancelRequest",
    "CustomerPortalSubscriptionsCancelRequestTypedDict",
    "CustomerPortalSubscriptionsCancelSecurity",
    "CustomerPortalSubscriptionsCancelSecurityTypedDict",
    "CustomerPortalSubscriptionsGetRequest",
    "CustomerPortalSubscriptionsGetRequestTypedDict",
    "CustomerPortalSubscriptionsGetSecurity",
    "CustomerPortalSubscriptionsGetSecurityTypedDict",
    "CustomerPortalSubscriptionsListQueryParamOrganizationIDFilter",
    "CustomerPortalSubscriptionsListQueryParamOrganizationIDFilterTypedDict",
    "CustomerPortalSubscriptionsListQueryParamProductIDFilter",
    "CustomerPortalSubscriptionsListQueryParamProductIDFilterTypedDict",
    "CustomerPortalSubscriptionsListRequest",
    "CustomerPortalSubscriptionsListRequestTypedDict",
    "CustomerPortalSubscriptionsListResponse",
    "CustomerPortalSubscriptionsListResponseTypedDict",
    "CustomerPortalSubscriptionsListSecurity",
    "CustomerPortalSubscriptionsListSecurityTypedDict",
    "CustomerPortalSubscriptionsUpdateRequest",
    "CustomerPortalSubscriptionsUpdateRequestTypedDict",
    "CustomerPortalSubscriptionsUpdateSecurity",
    "CustomerPortalSubscriptionsUpdateSecurityTypedDict",
    "CustomerProduct",
    "CustomerProductPrices",
    "CustomerProductPricesTypedDict",
    "CustomerProductTypedDict",
    "CustomerSession",
    "CustomerSessionCustomerExternalIDCreate",
    "CustomerSessionCustomerExternalIDCreateTypedDict",
    "CustomerSessionCustomerIDCreate",
    "CustomerSessionCustomerIDCreateTypedDict",
    "CustomerSessionTypedDict",
    "CustomerSessionsCreateCustomerSessionCreate",
    "CustomerSessionsCreateCustomerSessionCreateTypedDict",
    "CustomerSortProperty",
    "CustomerState",
    "CustomerStateBenefitGrant",
    "CustomerStateBenefitGrantProperties",
    "CustomerStateBenefitGrantPropertiesTypedDict",
    "CustomerStateBenefitGrantTypedDict",
    "CustomerStateMetadata",
    "CustomerStateMetadataTypedDict",
    "CustomerStateSubscription",
    "CustomerStateSubscriptionCustomFieldData",
    "CustomerStateSubscriptionCustomFieldDataTypedDict",
    "CustomerStateSubscriptionMetadata",
    "CustomerStateSubscriptionMetadataTypedDict",
    "CustomerStateSubscriptionTypedDict",
    "CustomerStateTaxID",
    "CustomerStateTaxIDTypedDict",
    "CustomerStateTypedDict",
    "CustomerSubscription",
    "CustomerSubscriptionCancel",
    "CustomerSubscriptionCancelTypedDict",
    "CustomerSubscriptionPrice",
    "CustomerSubscriptionPriceTypedDict",
    "CustomerSubscriptionPrices",
    "CustomerSubscriptionPricesTypedDict",
    "CustomerSubscriptionProduct",
    "CustomerSubscriptionProductPrices",
    "CustomerSubscriptionProductPricesTypedDict",
    "CustomerSubscriptionProductTypedDict",
    "CustomerSubscriptionSortProperty",
    "CustomerSubscriptionTypedDict",
    "CustomerSubscriptionUpdate",
    "CustomerSubscriptionUpdateProduct",
    "CustomerSubscriptionUpdateProductTypedDict",
    "CustomerSubscriptionUpdateTypedDict",
    "CustomerTaxID",
    "CustomerTaxIDTypedDict",
    "CustomerTypedDict",
    "CustomerUpdate",
    "CustomerUpdateMetadata",
    "CustomerUpdateMetadataTypedDict",
    "CustomerUpdateTaxID",
    "CustomerUpdateTaxIDTypedDict",
    "CustomerUpdateTypedDict",
    "CustomersDeleteExternalRequest",
    "CustomersDeleteExternalRequestTypedDict",
    "CustomersDeleteRequest",
    "CustomersDeleteRequestTypedDict",
    "CustomersGetExternalRequest",
    "CustomersGetExternalRequestTypedDict",
    "CustomersGetRequest",
    "CustomersGetRequestTypedDict",
    "CustomersGetStateExternalRequest",
    "CustomersGetStateExternalRequestTypedDict",
    "CustomersGetStateRequest",
    "CustomersGetStateRequestTypedDict",
    "CustomersListQueryParamOrganizationIDFilter",
    "CustomersListQueryParamOrganizationIDFilterTypedDict",
    "CustomersListRequest",
    "CustomersListRequestTypedDict",
    "CustomersListResponse",
    "CustomersListResponseTypedDict",
    "CustomersUpdateExternalRequest",
    "CustomersUpdateExternalRequestTypedDict",
    "CustomersUpdateRequest",
    "CustomersUpdateRequestTypedDict",
    "Discount",
    "DiscountCreate",
    "DiscountCreateTypedDict",
    "DiscountDuration",
    "DiscountFixedOnceForeverDuration",
    "DiscountFixedOnceForeverDurationBase",
    "DiscountFixedOnceForeverDurationBaseMetadata",
    "DiscountFixedOnceForeverDurationBaseMetadataTypedDict",
    "DiscountFixedOnceForeverDurationBaseTypedDict",
    "DiscountFixedOnceForeverDurationCreate",
    "DiscountFixedOnceForeverDurationCreateMetadata",
    "DiscountFixedOnceForeverDurationCreateMetadataTypedDict",
    "DiscountFixedOnceForeverDurationCreateTypedDict",
    "DiscountFixedOnceForeverDurationMetadata",
    "DiscountFixedOnceForeverDurationMetadataTypedDict",
    "DiscountFixedOnceForeverDurationTypedDict",
    "DiscountFixedRepeatDuration",
    "DiscountFixedRepeatDurationBase",
    "DiscountFixedRepeatDurationBaseMetadata",
    "DiscountFixedRepeatDurationBaseMetadataTypedDict",
    "DiscountFixedRepeatDurationBaseTypedDict",
    "DiscountFixedRepeatDurationCreate",
    "DiscountFixedRepeatDurationCreateMetadata",
    "DiscountFixedRepeatDurationCreateMetadataTypedDict",
    "DiscountFixedRepeatDurationCreateTypedDict",
    "DiscountFixedRepeatDurationMetadata",
    "DiscountFixedRepeatDurationMetadataTypedDict",
    "DiscountFixedRepeatDurationTypedDict",
    "DiscountIDFilter",
    "DiscountIDFilterTypedDict",
    "DiscountPercentageOnceForeverDuration",
    "DiscountPercentageOnceForeverDurationBase",
    "DiscountPercentageOnceForeverDurationBaseMetadata",
    "DiscountPercentageOnceForeverDurationBaseMetadataTypedDict",
    "DiscountPercentageOnceForeverDurationBaseTypedDict",
    "DiscountPercentageOnceForeverDurationCreate",
    "DiscountPercentageOnceForeverDurationCreateMetadata",
    "DiscountPercentageOnceForeverDurationCreateMetadataTypedDict",
    "DiscountPercentageOnceForeverDurationCreateTypedDict",
    "DiscountPercentageOnceForeverDurationMetadata",
    "DiscountPercentageOnceForeverDurationMetadataTypedDict",
    "DiscountPercentageOnceForeverDurationTypedDict",
    "DiscountPercentageRepeatDuration",
    "DiscountPercentageRepeatDurationBase",
    "DiscountPercentageRepeatDurationBaseMetadata",
    "DiscountPercentageRepeatDurationBaseMetadataTypedDict",
    "DiscountPercentageRepeatDurationBaseTypedDict",
    "DiscountPercentageRepeatDurationCreate",
    "DiscountPercentageRepeatDurationCreateMetadata",
    "DiscountPercentageRepeatDurationCreateMetadataTypedDict",
    "DiscountPercentageRepeatDurationCreateTypedDict",
    "DiscountPercentageRepeatDurationMetadata",
    "DiscountPercentageRepeatDurationMetadataTypedDict",
    "DiscountPercentageRepeatDurationTypedDict",
    "DiscountProduct",
    "DiscountProductTypedDict",
    "DiscountSortProperty",
    "DiscountType",
    "DiscountTypedDict",
    "DiscountUpdate",
    "DiscountUpdateMetadata",
    "DiscountUpdateMetadataTypedDict",
    "DiscountUpdateTypedDict",
    "DiscountsDeleteRequest",
    "DiscountsDeleteRequestTypedDict",
    "DiscountsGetRequest",
    "DiscountsGetRequestTypedDict",
    "DiscountsListQueryParamOrganizationIDFilter",
    "DiscountsListQueryParamOrganizationIDFilterTypedDict",
    "DiscountsListRequest",
    "DiscountsListRequestTypedDict",
    "DiscountsListResponse",
    "DiscountsListResponseTypedDict",
    "DiscountsUpdateRequest",
    "DiscountsUpdateRequestTypedDict",
    "DownloadableFileCreate",
    "DownloadableFileCreateTypedDict",
    "DownloadableFileRead",
    "DownloadableFileReadTypedDict",
    "DownloadableRead",
    "DownloadableReadTypedDict",
    "Event",
    "EventCreateCustomer",
    "EventCreateCustomerMetadata",
    "EventCreateCustomerMetadataTypedDict",
    "EventCreateCustomerTypedDict",
    "EventCreateExternalCustomer",
    "EventCreateExternalCustomerMetadata",
    "EventCreateExternalCustomerMetadataTypedDict",
    "EventCreateExternalCustomerTypedDict",
    "EventMetadata",
    "EventMetadataTypedDict",
    "EventSortProperty",
    "EventSource",
    "EventTypedDict",
    "EventsGetRequest",
    "EventsGetRequestTypedDict",
    "EventsIngest",
    "EventsIngestResponse",
    "EventsIngestResponseTypedDict",
    "EventsIngestTypedDict",
    "EventsListQueryParamCustomerIDFilter",
    "EventsListQueryParamCustomerIDFilterTypedDict",
    "EventsListQueryParamOrganizationIDFilter",
    "EventsListQueryParamOrganizationIDFilterTypedDict",
    "EventsListRequest",
    "EventsListRequestTypedDict",
    "EventsListResponse",
    "EventsListResponseTypedDict",
    "EventsModel",
    "EventsModelTypedDict",
    "ExistingProductPrice",
    "ExistingProductPriceTypedDict",
    "ExternalCustomerIDFilter",
    "ExternalCustomerIDFilterTypedDict",
    "ExternalOrganization",
    "ExternalOrganizationNameFilter",
    "ExternalOrganizationNameFilterTypedDict",
    "ExternalOrganizationSortProperty",
    "ExternalOrganizationTypedDict",
    "ExternalOrganizationsListRequest",
    "ExternalOrganizationsListRequestTypedDict",
    "ExternalOrganizationsListResponse",
    "ExternalOrganizationsListResponseTypedDict",
    "FileCreate",
    "FileCreateTypedDict",
    "FileDownload",
    "FileDownloadTypedDict",
    "FilePatch",
    "FilePatchTypedDict",
    "FileRead",
    "FileReadTypedDict",
    "FileServiceTypes",
    "FileUpload",
    "FileUploadCompleted",
    "FileUploadCompletedTypedDict",
    "FileUploadTypedDict",
    "FilesDeleteRequest",
    "FilesDeleteRequestTypedDict",
    "FilesListRequest",
    "FilesListRequestTypedDict",
    "FilesListResponse",
    "FilesListResponseTypedDict",
    "FilesUpdateRequest",
    "FilesUpdateRequestTypedDict",
    "FilesUpdateResponseFilesUpdate",
    "FilesUpdateResponseFilesUpdateTypedDict",
    "FilesUploadedRequest",
    "FilesUploadedRequestTypedDict",
    "FilesUploadedResponseFilesUploaded",
    "FilesUploadedResponseFilesUploadedTypedDict",
    "Filter",
    "FilterClause",
    "FilterClauseTypedDict",
    "FilterConjunction",
    "FilterOperator",
    "FilterTypedDict",
    "Func",
    "Funding",
    "FundingTypedDict",
    "GrantTypes",
    "HTTPValidationError",
    "HTTPValidationErrorData",
    "IntrospectTokenRequest",
    "IntrospectTokenRequestTokenTypeHint",
    "IntrospectTokenRequestTypedDict",
    "IntrospectTokenResponse",
    "IntrospectTokenResponseTypedDict",
    "Issue",
    "IssueTypedDict",
    "Items",
    "ItemsTypedDict",
    "Label",
    "LabelTypedDict",
    "LegacyRecurringProductPrice",
    "LegacyRecurringProductPriceCustom",
    "LegacyRecurringProductPriceCustomTypedDict",
    "LegacyRecurringProductPriceFixed",
    "LegacyRecurringProductPriceFixedTypedDict",
    "LegacyRecurringProductPriceFree",
    "LegacyRecurringProductPriceFreeTypedDict",
    "LegacyRecurringProductPriceTypedDict",
    "LicenseKeyActivate",
    "LicenseKeyActivateConditions",
    "LicenseKeyActivateConditionsTypedDict",
    "LicenseKeyActivateMeta",
    "LicenseKeyActivateMetaTypedDict",
    "LicenseKeyActivateTypedDict",
    "LicenseKeyActivationBase",
    "LicenseKeyActivationBaseTypedDict",
    "LicenseKeyActivationRead",
    "LicenseKeyActivationReadMeta",
    "LicenseKeyActivationReadMetaTypedDict",
    "LicenseKeyActivationReadTypedDict",
    "LicenseKeyCustomer",
    "LicenseKeyCustomerMetadata",
    "LicenseKeyCustomerMetadataTypedDict",
    "LicenseKeyCustomerTaxID",
    "LicenseKeyCustomerTaxIDTypedDict",
    "LicenseKeyCustomerTypedDict",
    "LicenseKeyDeactivate",
    "LicenseKeyDeactivateTypedDict",
    "LicenseKeyRead",
    "LicenseKeyReadTypedDict",
    "LicenseKeyStatus",
    "LicenseKeyUpdate",
    "LicenseKeyUpdateTypedDict",
    "LicenseKeyUser",
    "LicenseKeyUserTypedDict",
    "LicenseKeyValidate",
    "LicenseKeyValidateTypedDict",
    "LicenseKeyWithActivations",
    "LicenseKeyWithActivationsTypedDict",
    "LicenseKeysGetActivationRequest",
    "LicenseKeysGetActivationRequestTypedDict",
    "LicenseKeysGetRequest",
    "LicenseKeysGetRequestTypedDict",
    "LicenseKeysListQueryParamOrganizationIDFilter",
    "LicenseKeysListQueryParamOrganizationIDFilterTypedDict",
    "LicenseKeysListRequest",
    "LicenseKeysListRequestTypedDict",
    "LicenseKeysListResponse",
    "LicenseKeysListResponseTypedDict",
    "LicenseKeysUpdateRequest",
    "LicenseKeysUpdateRequestTypedDict",
    "ListResourceBenefit",
    "ListResourceBenefitGrant",
    "ListResourceBenefitGrantTypedDict",
    "ListResourceBenefitTypedDict",
    "ListResourceCheckout",
    "ListResourceCheckoutLink",
    "ListResourceCheckoutLinkTypedDict",
    "ListResourceCheckoutTypedDict",
    "ListResourceCustomField",
    "ListResourceCustomFieldTypedDict",
    "ListResourceCustomer",
    "ListResourceCustomerBenefitGrant",
    "ListResourceCustomerBenefitGrantTypedDict",
    "ListResourceCustomerOrder",
    "ListResourceCustomerOrderTypedDict",
    "ListResourceCustomerSubscription",
    "ListResourceCustomerSubscriptionTypedDict",
    "ListResourceCustomerTypedDict",
    "ListResourceDiscount",
    "ListResourceDiscountTypedDict",
    "ListResourceDownloadableRead",
    "ListResourceDownloadableReadTypedDict",
    "ListResourceEvent",
    "ListResourceEventTypedDict",
    "ListResourceExternalOrganization",
    "ListResourceExternalOrganizationTypedDict",
    "ListResourceFileRead",
    "ListResourceFileReadTypedDict",
    "ListResourceLicenseKeyRead",
    "ListResourceLicenseKeyReadTypedDict",
    "ListResourceMeter",
    "ListResourceMeterTypedDict",
    "ListResourceOAuth2Client",
    "ListResourceOAuth2ClientTypedDict",
    "ListResourceOrder",
    "ListResourceOrderTypedDict",
    "ListResourceOrganization",
    "ListResourceOrganizationTypedDict",
    "ListResourceProduct",
    "ListResourceProductTypedDict",
    "ListResourceRefund",
    "ListResourceRefundTypedDict",
    "ListResourceRepository",
    "ListResourceRepositoryTypedDict",
    "ListResourceSubscription",
    "ListResourceSubscriptionTypedDict",
    "ListResourceUnionPaymentMethodCardPaymentMethodGeneric",
    "ListResourceUnionPaymentMethodCardPaymentMethodGenericTypedDict",
    "Loc",
    "LocTypedDict",
    "Meta",
    "MetaTypedDict",
    "Metadata",
    "MetadataQuery",
    "MetadataQueryTypedDict",
    "MetadataTypedDict",
    "Meter",
    "MeterAggregation",
    "MeterAggregationTypedDict",
    "MeterCreate",
    "MeterCreateAggregation",
    "MeterCreateAggregationTypedDict",
    "MeterCreateMetadata",
    "MeterCreateMetadataTypedDict",
    "MeterCreateTypedDict",
    "MeterMetadata",
    "MeterMetadataTypedDict",
    "MeterQuantities",
    "MeterQuantitiesTypedDict",
    "MeterQuantity",
    "MeterQuantityTypedDict",
    "MeterSortProperty",
    "MeterTypedDict",
    "MeterUpdate",
    "MeterUpdateMetadata",
    "MeterUpdateMetadataTypedDict",
    "MeterUpdateTypedDict",
    "MetersEventsRequest",
    "MetersEventsRequestTypedDict",
    "MetersEventsResponse",
    "MetersEventsResponseTypedDict",
    "MetersGetRequest",
    "MetersGetRequestTypedDict",
    "MetersListQueryParamOrganizationIDFilter",
    "MetersListQueryParamOrganizationIDFilterTypedDict",
    "MetersListRequest",
    "MetersListRequestTypedDict",
    "MetersListResponse",
    "MetersListResponseTypedDict",
    "MetersQuantitiesQueryParamCustomerIDFilter",
    "MetersQuantitiesQueryParamCustomerIDFilterTypedDict",
    "MetersQuantitiesRequest",
    "MetersQuantitiesRequestTypedDict",
    "MetersUpdateRequest",
    "MetersUpdateRequestTypedDict",
    "Metric",
    "MetricPeriod",
    "MetricPeriodTypedDict",
    "MetricType",
    "MetricTypedDict",
    "Metrics",
    "MetricsGetQueryParamCustomerIDFilter",
    "MetricsGetQueryParamCustomerIDFilterTypedDict",
    "MetricsGetQueryParamOrganizationIDFilter",
    "MetricsGetQueryParamOrganizationIDFilterTypedDict",
    "MetricsGetQueryParamProductIDFilter",
    "MetricsGetQueryParamProductIDFilterTypedDict",
    "MetricsGetRequest",
    "MetricsGetRequestTypedDict",
    "MetricsIntervalLimit",
    "MetricsIntervalLimitTypedDict",
    "MetricsIntervalsLimits",
    "MetricsIntervalsLimitsTypedDict",
    "MetricsLimits",
    "MetricsLimitsTypedDict",
    "MetricsResponse",
    "MetricsResponseTypedDict",
    "MetricsTypedDict",
    "NotOpenCheckout",
    "NotOpenCheckoutData",
    "NotPermitted",
    "NotPermittedData",
    "OAuth2Client",
    "OAuth2ClientConfiguration",
    "OAuth2ClientConfigurationGrantTypes",
    "OAuth2ClientConfigurationTokenEndpointAuthMethod",
    "OAuth2ClientConfigurationTypedDict",
    "OAuth2ClientConfigurationUpdate",
    "OAuth2ClientConfigurationUpdateGrantTypes",
    "OAuth2ClientConfigurationUpdateTokenEndpointAuthMethod",
    "OAuth2ClientConfigurationUpdateTypedDict",
    "OAuth2ClientPublic",
    "OAuth2ClientPublicTypedDict",
    "OAuth2ClientTypedDict",
    "Oauth2AuthorizeResponseOauth2Authorize",
    "Oauth2AuthorizeResponseOauth2AuthorizeTypedDict",
    "Oauth2ClientsListRequest",
    "Oauth2ClientsListRequestTypedDict",
    "Oauth2ClientsListResponse",
    "Oauth2ClientsListResponseTypedDict",
    "Oauth2ClientsOauth2DeleteClientRequest",
    "Oauth2ClientsOauth2DeleteClientRequestTypedDict",
    "Oauth2ClientsOauth2GetClientRequest",
    "Oauth2ClientsOauth2GetClientRequestTypedDict",
    "Oauth2ClientsOauth2UpdateClientRequest",
    "Oauth2ClientsOauth2UpdateClientRequestTypedDict",
    "Oauth2RequestTokenRequestBody",
    "Oauth2RequestTokenRequestBodyTypedDict",
    "Oauth2UserinfoResponseOauth2Userinfo",
    "Oauth2UserinfoResponseOauth2UserinfoTypedDict",
    "Order",
    "OrderBillingReason",
    "OrderCustomFieldData",
    "OrderCustomFieldDataTypedDict",
    "OrderCustomer",
    "OrderCustomerMetadata",
    "OrderCustomerMetadataTypedDict",
    "OrderCustomerTaxID",
    "OrderCustomerTaxIDTypedDict",
    "OrderCustomerTypedDict",
    "OrderDiscount",
    "OrderDiscountTypedDict",
    "OrderIDFilter",
    "OrderIDFilterTypedDict",
    "OrderInvoice",
    "OrderInvoiceTypedDict",
    "OrderItemSchema",
    "OrderItemSchemaTypedDict",
    "OrderMetadata",
    "OrderMetadataTypedDict",
    "OrderProduct",
    "OrderProductPrice",
    "OrderProductPriceTypedDict",
    "OrderProductTypedDict",
    "OrderSortProperty",
    "OrderStatus",
    "OrderSubscription",
    "OrderSubscriptionMetadata",
    "OrderSubscriptionMetadataTypedDict",
    "OrderSubscriptionTypedDict",
    "OrderTypedDict",
    "OrderUser",
    "OrderUserTypedDict",
    "OrdersGetRequest",
    "OrdersGetRequestTypedDict",
    "OrdersInvoiceRequest",
    "OrdersInvoiceRequestTypedDict",
    "OrdersListQueryParamCustomerIDFilter",
    "OrdersListQueryParamCustomerIDFilterTypedDict",
    "OrdersListQueryParamOrganizationIDFilter",
    "OrdersListQueryParamOrganizationIDFilterTypedDict",
    "OrdersListQueryParamProductIDFilter",
    "OrdersListQueryParamProductIDFilterTypedDict",
    "OrdersListRequest",
    "OrdersListRequestTypedDict",
    "OrdersListResponse",
    "OrdersListResponseTypedDict",
    "Organization",
    "OrganizationAvatarFileCreate",
    "OrganizationAvatarFileCreateTypedDict",
    "OrganizationAvatarFileRead",
    "OrganizationAvatarFileReadTypedDict",
    "OrganizationCreate",
    "OrganizationCreateTypedDict",
    "OrganizationDetails",
    "OrganizationDetailsTypedDict",
    "OrganizationFeatureSettings",
    "OrganizationFeatureSettingsTypedDict",
    "OrganizationID",
    "OrganizationIDFilter",
    "OrganizationIDFilterTypedDict",
    "OrganizationIDTypedDict",
    "OrganizationProfileSettings",
    "OrganizationProfileSettingsTypedDict",
    "OrganizationSocialLink",
    "OrganizationSocialLinkTypedDict",
    "OrganizationSocialPlatforms",
    "OrganizationSortProperty",
    "OrganizationSubscribePromoteSettings",
    "OrganizationSubscribePromoteSettingsTypedDict",
    "OrganizationSubscriptionSettings",
    "OrganizationSubscriptionSettingsTypedDict",
    "OrganizationTypedDict",
    "OrganizationUpdate",
    "OrganizationUpdateTypedDict",
    "OrganizationsGetRequest",
    "OrganizationsGetRequestTypedDict",
    "OrganizationsListRequest",
    "OrganizationsListRequestTypedDict",
    "OrganizationsListResponse",
    "OrganizationsListResponseTypedDict",
    "OrganizationsUpdateRequest",
    "OrganizationsUpdateRequestTypedDict",
    "Pagination",
    "PaginationTypedDict",
    "PaymentError",
    "PaymentErrorData",
    "PaymentMethodCard",
    "PaymentMethodCardData",
    "PaymentMethodCardDataTypedDict",
    "PaymentMethodCardTypedDict",
    "PaymentMethodGeneric",
    "PaymentMethodGenericTypedDict",
    "PaymentProcessor",
    "Permission",
    "PlatformFilter",
    "PlatformFilterTypedDict",
    "Platforms",
    "Pledge",
    "PledgeState",
    "PledgeType",
    "PledgeTypedDict",
    "Pledger",
    "PledgerTypedDict",
    "PreviousProperties",
    "PreviousPropertiesTypedDict",
    "Price",
    "PriceTypedDict",
    "Prices",
    "PricesTypedDict",
    "Product",
    "ProductBenefitsUpdate",
    "ProductBenefitsUpdateTypedDict",
    "ProductBillingType",
    "ProductBillingTypeFilter",
    "ProductBillingTypeFilterTypedDict",
    "ProductCreate",
    "ProductCreateMetadata",
    "ProductCreateMetadataTypedDict",
    "ProductCreatePrices",
    "ProductCreatePricesTypedDict",
    "ProductCreateTypedDict",
    "ProductIDFilter",
    "ProductIDFilterTypedDict",
    "ProductMediaFileCreate",
    "ProductMediaFileCreateTypedDict",
    "ProductMediaFileRead",
    "ProductMediaFileReadTypedDict",
    "ProductMetadata",
    "ProductMetadataTypedDict",
    "ProductPrice",
    "ProductPriceCustom",
    "ProductPriceCustomCreate",
    "ProductPriceCustomCreateTypedDict",
    "ProductPriceCustomTypedDict",
    "ProductPriceFixed",
    "ProductPriceFixedCreate",
    "ProductPriceFixedCreateTypedDict",
    "ProductPriceFixedTypedDict",
    "ProductPriceFree",
    "ProductPriceFreeCreate",
    "ProductPriceFreeCreateTypedDict",
    "ProductPriceFreeTypedDict",
    "ProductPriceType",
    "ProductPriceTypeFilter",
    "ProductPriceTypeFilterTypedDict",
    "ProductPriceTypedDict",
    "ProductSortProperty",
    "ProductTypedDict",
    "ProductUpdate",
    "ProductUpdateMetadata",
    "ProductUpdateMetadataTypedDict",
    "ProductUpdatePrices",
    "ProductUpdatePricesTypedDict",
    "ProductUpdateTypedDict",
    "ProductsGetRequest",
    "ProductsGetRequestTypedDict",
    "ProductsListQueryParamOrganizationIDFilter",
    "ProductsListQueryParamOrganizationIDFilterTypedDict",
    "ProductsListRequest",
    "ProductsListRequestTypedDict",
    "ProductsListResponse",
    "ProductsListResponseTypedDict",
    "ProductsUpdateBenefitsRequest",
    "ProductsUpdateBenefitsRequestTypedDict",
    "ProductsUpdateRequest",
    "ProductsUpdateRequestTypedDict",
    "Properties",
    "PropertiesTypedDict",
    "PropertyAggregation",
    "PropertyAggregationTypedDict",
    "QueryParamBenefitIDFilter",
    "QueryParamBenefitIDFilterTypedDict",
    "QueryParamBenefitTypeFilter",
    "QueryParamBenefitTypeFilterTypedDict",
    "QueryParamCheckoutIDFilter",
    "QueryParamCheckoutIDFilterTypedDict",
    "QueryParamCustomerIDFilter",
    "QueryParamCustomerIDFilterTypedDict",
    "QueryParamDiscountIDFilter",
    "QueryParamDiscountIDFilterTypedDict",
    "QueryParamExternalCustomerIDFilter",
    "QueryParamExternalCustomerIDFilterTypedDict",
    "QueryParamOrderIDFilter",
    "QueryParamOrderIDFilterTypedDict",
    "QueryParamOrganizationIDFilter",
    "QueryParamOrganizationIDFilterTypedDict",
    "QueryParamPlatformFilter",
    "QueryParamPlatformFilterTypedDict",
    "QueryParamProductBillingTypeFilter",
    "QueryParamProductBillingTypeFilterTypedDict",
    "QueryParamProductIDFilter",
    "QueryParamProductIDFilterTypedDict",
    "QueryParamProductPriceTypeFilter",
    "QueryParamProductPriceTypeFilterTypedDict",
    "QueryParamRepositoryNameFilter",
    "QueryParamRepositoryNameFilterTypedDict",
    "QueryParamSubscriptionIDFilter",
    "QueryParamSubscriptionIDFilterTypedDict",
    "Reactions",
    "ReactionsTypedDict",
    "RefreshTokenRequest",
    "RefreshTokenRequestTypedDict",
    "Refund",
    "RefundAmountTooHigh",
    "RefundAmountTooHighData",
    "RefundCreate",
    "RefundCreateMetadata",
    "RefundCreateMetadataTypedDict",
    "RefundCreateTypedDict",
    "RefundIDFilter",
    "RefundIDFilterTypedDict",
    "RefundMetadata",
    "RefundMetadataTypedDict",
    "RefundReason",
    "RefundSortProperty",
    "RefundStatus",
    "RefundTypedDict",
    "RefundedAlready",
    "RefundedAlreadyData",
    "RefundsListQueryParamCustomerIDFilter",
    "RefundsListQueryParamCustomerIDFilterTypedDict",
    "RefundsListQueryParamOrganizationIDFilter",
    "RefundsListQueryParamOrganizationIDFilterTypedDict",
    "RefundsListRequest",
    "RefundsListRequestTypedDict",
    "RefundsListResponse",
    "RefundsListResponseTypedDict",
    "RepositoriesGetRequest",
    "RepositoriesGetRequestTypedDict",
    "RepositoriesListRequest",
    "RepositoriesListRequestTypedDict",
    "RepositoriesListResponse",
    "RepositoriesListResponseTypedDict",
    "RepositoriesUpdateRequest",
    "RepositoriesUpdateRequestTypedDict",
    "Repository",
    "RepositoryNameFilter",
    "RepositoryNameFilterTypedDict",
    "RepositoryProfileSettings",
    "RepositoryProfileSettingsTypedDict",
    "RepositoryProfileSettingsUpdate",
    "RepositoryProfileSettingsUpdateTypedDict",
    "RepositorySortProperty",
    "RepositoryTypedDict",
    "RepositoryUpdate",
    "RepositoryUpdateTypedDict",
    "ResourceNotFound",
    "ResourceNotFoundData",
    "RevokeTokenRequest",
    "RevokeTokenRequestTypedDict",
    "RevokeTokenResponse",
    "RevokeTokenResponseTypedDict",
    "S3DownloadURL",
    "S3DownloadURLTypedDict",
    "S3FileCreateMultipart",
    "S3FileCreateMultipartTypedDict",
    "S3FileCreatePart",
    "S3FileCreatePartTypedDict",
    "S3FileUploadCompletedPart",
    "S3FileUploadCompletedPartTypedDict",
    "S3FileUploadMultipart",
    "S3FileUploadMultipartTypedDict",
    "S3FileUploadPart",
    "S3FileUploadPartTypedDict",
    "SDKError",
    "Scope",
    "Security",
    "SecurityTypedDict",
    "SourceFilter",
    "SourceFilterTypedDict",
    "State",
    "SubType",
    "Subscription",
    "SubscriptionCancel",
    "SubscriptionCancelTypedDict",
    "SubscriptionCustomer",
    "SubscriptionCustomerMetadata",
    "SubscriptionCustomerMetadataTypedDict",
    "SubscriptionCustomerTypedDict",
    "SubscriptionDiscount",
    "SubscriptionDiscountTypedDict",
    "SubscriptionIDFilter",
    "SubscriptionIDFilterTypedDict",
    "SubscriptionPrices",
    "SubscriptionPricesTypedDict",
    "SubscriptionProrationBehavior",
    "SubscriptionRecurringInterval",
    "SubscriptionSortProperty",
    "SubscriptionStatus",
    "SubscriptionTypedDict",
    "SubscriptionUpdate",
    "SubscriptionUpdateProduct",
    "SubscriptionUpdateProductTypedDict",
    "SubscriptionUpdateTypedDict",
    "SubscriptionUser",
    "SubscriptionUserTypedDict",
    "SubscriptionsExportRequest",
    "SubscriptionsExportRequestTypedDict",
    "SubscriptionsGetRequest",
    "SubscriptionsGetRequestTypedDict",
    "SubscriptionsListQueryParamOrganizationIDFilter",
    "SubscriptionsListQueryParamOrganizationIDFilterTypedDict",
    "SubscriptionsListRequest",
    "SubscriptionsListRequestTypedDict",
    "SubscriptionsListResponse",
    "SubscriptionsListResponseTypedDict",
    "SubscriptionsRevokeRequest",
    "SubscriptionsRevokeRequestTypedDict",
    "SubscriptionsUpdateRequest",
    "SubscriptionsUpdateRequestTypedDict",
    "SwitchingFrom",
    "TaxID",
    "TaxIDFormat",
    "TaxIDTypedDict",
    "TimeInterval",
    "Timeframe",
    "TokenEndpointAuthMethod",
    "TokenResponse",
    "TokenResponseTypedDict",
    "TokenType",
    "TokenTypeHint",
    "Unauthorized",
    "UnauthorizedData",
    "UserInfoOrganization",
    "UserInfoOrganizationTypedDict",
    "UserInfoUser",
    "UserInfoUserTypedDict",
    "ValidatedLicenseKey",
    "ValidatedLicenseKeyTypedDict",
    "ValidationError",
    "ValidationErrorTypedDict",
    "Value",
    "ValueTypedDict",
    "WebhookBenefitCreatedPayload",
    "WebhookBenefitCreatedPayloadTypedDict",
    "WebhookBenefitGrantCreatedPayload",
    "WebhookBenefitGrantCreatedPayloadTypedDict",
    "WebhookBenefitGrantRevokedPayload",
    "WebhookBenefitGrantRevokedPayloadTypedDict",
    "WebhookBenefitGrantUpdatedPayload",
    "WebhookBenefitGrantUpdatedPayloadTypedDict",
    "WebhookBenefitUpdatedPayload",
    "WebhookBenefitUpdatedPayloadTypedDict",
    "WebhookCheckoutCreatedPayload",
    "WebhookCheckoutCreatedPayloadTypedDict",
    "WebhookCheckoutUpdatedPayload",
    "WebhookCheckoutUpdatedPayloadTypedDict",
    "WebhookCustomerCreatedPayload",
    "WebhookCustomerCreatedPayloadTypedDict",
    "WebhookCustomerDeletedPayload",
    "WebhookCustomerDeletedPayloadTypedDict",
    "WebhookCustomerStateChangedPayload",
    "WebhookCustomerStateChangedPayloadTypedDict",
    "WebhookCustomerUpdatedPayload",
    "WebhookCustomerUpdatedPayloadTypedDict",
    "WebhookOrderCreatedPayload",
    "WebhookOrderCreatedPayloadTypedDict",
    "WebhookOrderPaidPayload",
    "WebhookOrderPaidPayloadTypedDict",
    "WebhookOrderRefundedPayload",
    "WebhookOrderRefundedPayloadTypedDict",
    "WebhookOrderUpdatedPayload",
    "WebhookOrderUpdatedPayloadTypedDict",
    "WebhookOrganizationUpdatedPayload",
    "WebhookOrganizationUpdatedPayloadTypedDict",
    "WebhookPledgeCreatedPayload",
    "WebhookPledgeCreatedPayloadTypedDict",
    "WebhookPledgeUpdatedPayload",
    "WebhookPledgeUpdatedPayloadTypedDict",
    "WebhookProductCreatedPayload",
    "WebhookProductCreatedPayloadTypedDict",
    "WebhookProductUpdatedPayload",
    "WebhookProductUpdatedPayloadTypedDict",
    "WebhookRefundCreatedPayload",
    "WebhookRefundCreatedPayloadTypedDict",
    "WebhookRefundUpdatedPayload",
    "WebhookRefundUpdatedPayloadTypedDict",
    "WebhookSubscriptionActivePayload",
    "WebhookSubscriptionActivePayloadTypedDict",
    "WebhookSubscriptionCanceledPayload",
    "WebhookSubscriptionCanceledPayloadTypedDict",
    "WebhookSubscriptionCreatedPayload",
    "WebhookSubscriptionCreatedPayloadTypedDict",
    "WebhookSubscriptionRevokedPayload",
    "WebhookSubscriptionRevokedPayloadTypedDict",
    "WebhookSubscriptionUncanceledPayload",
    "WebhookSubscriptionUncanceledPayloadTypedDict",
    "WebhookSubscriptionUpdatedPayload",
    "WebhookSubscriptionUpdatedPayloadTypedDict",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class LicenseKeyStatus(str, Enum):
    GRANTED = "granted"
    REVOKED = "revoked"
    DISABLED = "disabled"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DiscountSortProperty(str, Enum):
    CREATED_AT = "created_at"
    MINUS_CREATED_AT = "-created_at"
    NAME = "name"
    MINUS_NAME = "-name"
    CODE = "code"
    MINUS_CODE = "-code"
    REDEMPTIONS_COUNT = "redemptions_count"
    MINUS_REDEMPTIONS_COUNT = "-redemptions_count"
